var dynamsoft = self.dynamsoft || {};
dynamsoft.TaskQueue = dynamsoft.TaskQueue || (function(){
    var TaskQueue = function(){
        /// <summary>
        /// @class TaskQueue
        /// </summary>

        this._queue = [];
        this.isWorking = false;

        /// <param name="timeout" type="int">
        /// Timeout between task.
        /// Between the interval, other work can be done, such as UI-response work.
        /// </param>
        this.timeout = 100;
    };

    TaskQueue.prototype.push = function(task, context, args){
        /// <summary>
        /// Push task. If <span>!isWorking</span>, start the task queue automatically.
        /// </summary>

        this._queue.push({
            "task": task,
            "context": context,
            "args": args
        });
        if(!this.isWorking){
            this.next();
        }
    };

    TaskQueue.prototype.unshift = function(task, context, args){
        /// <summary>
        /// Push task. If <span>!isWorking</span>, start the task queue automatically.
        /// </summary>

        this._queue.unshift({
            "task": task,
            "context": context,
            "args": args
        });
        if(!this.isWorking){
            this.next();
        }
    };

    TaskQueue.prototype.next = function(){
        /// <summary>
        /// Do the next task.
        /// You need to call it manually in the end of your task.
        /// To assure <function>next</function> will be called,
        /// in some case you can put the function in <span>finally</span>,
        /// in other case you should carefully handle <span>setTimeout</span>.
        /// </summary>

        if(this._queue.length == 0){
            this.isWorking = false;
            return;
        }
        this.isWorking = true;
        var item = this._queue.shift();
        var task = item.task;
        var taskContext = item.context ? item.context : self;
        var taskArguments = item.args ? item.args : [];
        setTimeout(function(){
            task.apply(taskContext, taskArguments);
        }, this.timeout);
    };

    /*
    TaskQueue.test = function(){
        var taskQueue = new TaskQueue();
        var task = function(mess){
            console.log(mess);
            taskQueue.next();
        };
        for(var i = 0; i < 100; ++i){
            taskQueue.push(task, null, [i]);
        }
    };*/

    return TaskQueue;
})();
var dynamsoft = self.dynamsoft || {};
dynamsoft.dbrEnv = dynamsoft.dbrEnv || {};
if(dynamsoft.dbrEnv.logLevel == undefined){dynamsoft.dbrEnv.logLevel = 3;}
dynamsoft.BarcodeReader = dynamsoft.BarcodeReader || (function(){
    var BarcodeReader = function(licenseKey){
        licenseKey = licenseKey || dynamsoft.dbrEnv.licenseKey || "";
        if(!(typeof licenseKey == 'string' || typeof licenseKey == 'object' && licenseKey instanceof String)){
            throw TypeError("'Constructor BarcodeReader(licenseKey)': Type of 'licenseKey' should be 'String'.");
        }
        this._licenseKey = licenseKey;
        this._instance = new dynamsoft.BarcodeReader._BarcodeReaderWasm(this._licenseKey);
        if(0 == this._instance){
            throw new dynamsoft.BarcodeReader.BarcodeReaderException(dynamsoft.BarcodeReader.EnumErrorCode.DBR_NULL_REFERENCE, "Can't create BarcodeReader instance.");
        }
    };

    BarcodeReader._jsVersion = "6.3.0";
    BarcodeReader._jsEditVersion = '20180802';
    BarcodeReader.version = "loading...(JS " + BarcodeReader._jsVersion + '.' + BarcodeReader._jsEditVersion + ")";

    BarcodeReader.prototype.deleteInstance = function(){
        this._instance.delete();
    };

    // Blob 
    BarcodeReader.prototype._decodeBlob = function(blob, templateName){
        var barcodeReader = this;
        return new Promise(function(resolve, reject){
            if(!(blob instanceof Blob)){
                throw TypeError("'_decodeBlob(blob, templateName)': Type of 'blob' should be 'Blob'.");
            }
            templateName = templateName || "";
            var objUrl = URL.createObjectURL(blob);
            var image = new Image();
            image.dbrObjUrl = objUrl;
            image.src = objUrl;
            image.onload = function(){
                resolve(image);
            };
            image.onerror = function(){
                reject(TypeError("'_decodeBlob(blob, templateName)': Can't convert the blob to image."));
            };
        }).then(function(image){
            return barcodeReader._decodeImage(image);
        });
    };

    // ArrayBuffer
    BarcodeReader.prototype._decodeArrayBuffer = function(arrayBuffer, templateName){
        var barcodeReader = this;
        return new Promise(function(resolve){
            if(!(arrayBuffer instanceof ArrayBuffer)){
                throw TypeError("'_decodeBlob(arrayBuffer, templateName)': Type of 'arrayBuffer' should be 'ArrayBuffer'.");
            }
            templateName = templateName || "";
            resolve();
        }).then(function(){
            return barcodeReader._decodeBlob(new Blob(arrayBuffer), templateName);
        });
    };

    // Uint8Array
    BarcodeReader.prototype._decodeUint8Array = function(uint8Array, templateName){
        var barcodeReader = this;
        return new Promise(function(resolve){
            if(!(uint8Array instanceof Uint8Array) && !(self.Uint8ClampedArray && uint8Array instanceof Uint8ClampedArray)){
                throw TypeError("'_decodeBlob(uint8Array, templateName)': Type of 'uint8Array' should be 'Uint8Array'.");
            }
            templateName = templateName || "";
            resolve(uint8Array);
        }).then(function(uint8Array){
            return barcodeReader._decodeBlob(new Blob(uint8Array), templateName);
        });
    };

    // Image
    BarcodeReader.prototype._decodeImage = function(image, templateName){
        var barcodeReader = this;
        return new Promise(function(resolve){
            if(!(image instanceof HTMLImageElement)){
                throw TypeError("'_decodeImage(image, templateName)': Type of 'image' should be 'HTMLImageElement'.");
            }
            if(image.crossOrigin && "anonymous" != image.crossOrigin){
                throw "cors";
            }
            templateName = templateName || "";
            resolve();
        }).then(function(){
            var cvs = document.createElement('canvas');
            cvs.width = image.naturalWidth;
            cvs.height = image.naturalHeight;
            var ctx = cvs.getContext('2d');
            ctx.drawImage(image, 0, 0);
            if(image.dbrObjUrl){
                URL.revokeObjectURL(image.dbrObjUrl);
            }
            return barcodeReader._decodeCanvas(cvs, templateName);
        });
    };

    // HTMLCanvasElement
    BarcodeReader.prototype._decodeCanvas = function(canvas, templateName){
        var barcodeReader = this;
        return new Promise(function(resolve){
            if(!(canvas instanceof HTMLCanvasElement)){
                throw TypeError("'_decodeCanvas(canvas, templateName)': Type of 'canvas' should be 'HTMLCanvasElement'.");
            }
            if(canvas.crossOrigin && "anonymous" != canvas.crossOrigin){
                throw "cors";
            }
            templateName = templateName || "";

            var ctx = canvas.getContext('2d');
            var data = ctx.getImageData(0,0,canvas.width,canvas.height).data;
            resolve(data);
        }).then(function(data){
            return barcodeReader._decodeRawImageUint8Array(data, canvas.width, canvas.height, canvas.width * 4, dynamsoft.BarcodeReader.EnumImagePixelFormat.IPF_ARGB_8888, templateName);
        });
    };

    // HTMLVideoElement
    BarcodeReader.prototype._decodeVideo = BarcodeReader.prototype.decodeVideo = function(video){
        var barcodeReader = this;
        var templateName;
        var arg = arguments;
        return new Promise(function(resolve){
            if(!(video instanceof HTMLVideoElement)){
                throw TypeError("'_decodeVideo(video [ [, sx, sy, sWidth, sHeight], dWidth, dHeight] [, templateName] )': Type of 'video' should be 'HTMLVideoElement'.");
            }
            if(video.crossOrigin && "anonymous" != video.crossOrigin){
                throw "cors";
            }
            var sx, sy, sWidth, sHeight, dWidth, dHeight;
            if(arg.length <= 2){
                sx = sy = 0;
                sWidth = dWidth = video.videoWidth;
                sHeight = dHeight = video.videoHeight;
            }else if(arg.length <= 4){
                sx = sy = 0;
                sWidth = video.videoWidth;
                sHeight = video.videoHeight;
                dWidth = arg[1];
                dHeight = arg[2];
            }else{//arg.length <= 8
                sx = arg[1];
                sy = arg[2];
                sWidth = arg[3];
                sHeight = arg[4];
                dWidth = arg[5];
                dHeight = arg[6];
            }
            templateName = (typeof arg[arg.length - 1] == "string") ? arg[arg.length - 1] : "";
            var cvs = document.createElement('canvas');
            cvs.width = dWidth;
            cvs.height = dHeight;
            var ctx = cvs.getContext('2d');
            ctx.drawImage(video,sx,sy,sWidth,sHeight,0,0,dWidth,dHeight);
            resolve(cvs);
        }).then(function(cvs){
            return barcodeReader._decodeCanvas(cvs, templateName);
        });
    };

    // String // api match C#
    BarcodeReader.prototype._decodeBase64 = BarcodeReader.prototype.decodeBase64String = function(base64Str, templateName){
        var barcodeReader = this;
        return new Promise(function(resolve){
            if(!(typeof base64Str == 'string' || typeof base64Str == 'object' && base64Str instanceof String)){
                throw TypeError("'decodeBase64(base64Str, templateName)': Type of 'base64Str' should be 'String'.");
            }
            if(base64Str.substring(0, 11) == "data:image/"){
                base64Str = base64Str.substring(base64Str.indexOf(',')+1);
            }
            templateName = templateName || "";
            var binaryStr = atob(base64Str);
            var n = binaryStr.length;
            var u8arr = new Uint8Array(n);
            while(n--){
                u8arr[n] = binaryStr.charCodeAt(n);
            }
            resolve(new Blob([u8arr]));
        }).then(function(blob){
            return barcodeReader._decodeBlob(blob, templateName);
        });
    };

    // String
    BarcodeReader.prototype._decodeUrl = function(url, templateName){
        var barcodeReader = this;
        return new Promise(function(resolve, reject){
            if(!(typeof url == 'string' || typeof url == 'object' && url instanceof String)){
                throw TypeError("'_decodeUrl(url, templateName)': Type of 'url' should be 'String'.");
            }
            templateName = templateName || "";
            // decodeBinaryStr for ie6-9
            // decodeArrayBuffer for H5
            var http = new XMLHttpRequest();
            http.open("GET", url, true);
            http.responseType = "blob";
            http.send();
            http.onloadend = function () {
                resolve(this.response);
            };
            http.onerror = function(){
                reject(http.error);
            };
        }).then(function(blob){
            return barcodeReader._decodeBlob(blob, templateName);
        });
    };

    // Blob
    BarcodeReader.prototype._decodeRawImageBlob = function(buffer, width, height, stride, enumImagePixelFormat, templateName){
        var barcodeReader = this;
        return new Promise(function(resolve, reject){
            if(!(buffer instanceof Blob)){
                throw TypeError("'_decodeRawImageBlob(buffer, width, height, stride, enumImagePixelFormat, templateName)': Type of 'buffer' should be 'Blob'.");
            }
            templateName = templateName || "";
            var freader = new FileReader();
            freader.readAsArrayBuffer(buffer);
            freader.onload = function(){
                resolve(freader.result);
            };
            freader.onerror = function(){
                reject(freader.error);
            };
        }).then(function(arrayBuffer){
            return barcodeReader._decodeRawImageUint8Array(new Uint8Array(arrayBuffer), width, height, stride, enumImagePixelFormat, templateName);
        });
    };

    // ArrayBuffer
    BarcodeReader.prototype._decodeRawImageArrayBuffer = function(buffer, width, height, stride, enumImagePixelFormat, templateName){
        var barcodeReader = this;
        return new Promise(function(resolve){
            if(!(buffer instanceof ArrayBuffer)){
                throw TypeError("'_decodeRawImageArrayBuffer(buffer, width, height, stride, enumImagePixelFormat, templateName)': Type of 'buffer' should be 'ArrayBuffer'.");
            }
            templateName = templateName || "";
            resolve();
        }).then(function(){
            return barcodeReader._decodeRawImageUint8Array(new Uint8Array(buffer), width, height, stride, enumImagePixelFormat, templateName);
        });
    };

    // Uint8Array
    BarcodeReader.prototype._decodeRawImageUint8Array = function(buffer, width, height, stride, enumImagePixelFormat, templateName){
        var barcodeReader = this;
        return new Promise(function(resolve){
            if(!(buffer instanceof Uint8Array) && !(self.Uint8ClampedArray && buffer instanceof Uint8ClampedArray)){
                throw TypeError("'_decodeRawImageUint8Array(buffer, width, height, stride, enumImagePixelFormat, templateName)': Type of 'buffer' should be 'Uint8Array'.");
            }
            templateName = templateName || "";
            resolve(handleRetJsonString(barcodeReader._instance.DecodeBuffer(buffer, width, height, stride, enumImagePixelFormat, templateName)));
        });
    };

    // Blob ArrayBuffer Uint8Array HTMLImageElement HTMLCanvasElement HTMLVideoElement base64 url
    BarcodeReader.prototype._decode = BarcodeReader.prototype.decodeFileInMemory = function(source, templateName){
        if(Blob && source instanceof Blob){
            return this._decodeBlob(source, templateName);
        }else if(self.ArrayBuffer && source instanceof ArrayBuffer){
            return this._decodeArrayBuffer(source, templateName);
        }else if((self.Uint8Array && source instanceof Uint8Array)||(self.Uint8ClampedArray && source instanceof Uint8ClampedArray)){
            return this._decodeUint8Array(source, templateName);
        }else if(self.HTMLImageElement && source instanceof HTMLImageElement){
            return this._decodeImage(source, templateName);
        }else if(self.HTMLCanvasElement && source instanceof HTMLCanvasElement){
            return this._decodeCanvas(source, templateName);
        }else if(self.HTMLVideoElement && source instanceof HTMLVideoElement){
            return this._decodeVideo(source, templateName);
        }else if(typeof source == 'string' || source instanceof String){
            if(source.substring(0, 11) == "data:image/"){
                return this._decodeBase64(source, templateName);
            }else{
                return this._decodeUrl(source, templateName);
            }
        }else{
            return Promise.reject(TypeError("'_decode(source, templateName)': Type of 'source' should be 'Blob', 'ArrayBuffer', 'Uint8Array', 'HTMLImageElement', 'HTMLCanvasElement', 'HTMLVideoElement', 'String(base64 with image mime)' or 'String(url)'."));
        }
    };

    // Blob ArrayBuffer Uint8Array
    BarcodeReader.prototype._decodeRawImage = BarcodeReader.prototype.decodeBuffer = function(source, width, height, stride, enumImagePixelFormat, templateName){
        if(Blob && source instanceof Blob){
            return this._decodeRawImageBlob(source, width, height, stride, enumImagePixelFormat, templateName);
        }else if(ArrayBuffer && source instanceof ArrayBuffer){
            return this._decodeRawImageArrayBuffer(source, width, height, stride, enumImagePixelFormat, templateName);
        }else if((self.Uint8Array && source instanceof Uint8Array)||(self.Uint8ClampedArray && source instanceof Uint8ClampedArray)){
            return this._decodeRawImageUint8Array(source, width, height, stride, enumImagePixelFormat, templateName);
        }else{
            return Promise.reject(TypeError("'_decodeRawImage(source, width, height, stride, enumImagePixelFormat, templateName)': Type of 'source' should be 'Blob', 'ArrayBuffer' or 'Uint8Array'."));
        }
    };

    var handleRetJsonString = function(wasmRet){
        var objRet = null;
        if(typeof wasmRet == 'string' || typeof wasmRet == 'object' && wasmRet instanceof String){
            objRet = JSON.parse(wasmRet);
        }else{
            objRet = wasmRet;
        }

        var e = BarcodeReader.EnumErrorCode;
        switch(objRet.exception){
        case e.DBR_SUCCESS:
        case e.DBR_LICENSE_INVALID:
        case e.DBR_1D_LICENSE_INVALID:
        case e.DBR_QR_LICENSE_INVALID:
        case e.DBR_PDF417_LICENSE_INVALID:
        case e.DBR_DATAMATRIX_LICENSE_INVALID:
        case e.DBR_DBRERR_AZTEC_LICENSE_INVALID:
        case e.DBR_RECOGNITION_TIMEOUT:
            if(objRet.textResult){
                for(var i = 0; i < objRet.textResult.length; ++i){
                    var aResult = objRet.textResult[i];
                    try{
                        aResult.BarcodeText = atob(aResult.BarcodeText);
                    }catch(ex){
                        aResult.BarcodeText = "";
                    }
                }
            }
            return objRet.textResult || objRet.localizationResultArray || objRet.Result || objRet.templateSettings || objRet.settings || objRet;
        default: 
            throw new BarcodeReader.BarcodeReaderException(objRet.exception, objRet.description);
        }
    };

    BarcodeReader.prototype.getAllLocalizationResults = function(){
        return handleRetJsonString(this._instance.GetAllLocalizationResults());
    };

    BarcodeReader.prototype.getAllParameterTemplateNames = function(){
        return handleRetJsonString(this._instance.GetAllParameterTemplateNames());
    };

    BarcodeReader.prototype.getRuntimeSettings = function(){
        return handleRetJsonString(this._instance.GetRuntimeSettings());
    };

    BarcodeReader.prototype.updateRuntimeSettings = function(settings){
        var //settingsObj, 
            settingsStr;
        if(typeof settings == 'string' || typeof settings == 'object' && settings instanceof String){ // string
            //settingsObj = JSON.parse(settings);
            settingsStr = settings;
        }else if(typeof settings == 'object'){// object
            //settingsObj = settings;
            settingsStr = JSON.stringify(settings);
        }else{ // other
            throw TypeError("'UpdateRuntimeSettings(settings)': Type of 'settings' should be 'String' or 'PlainObject'.");
        }
        handleRetJsonString(this._instance.UpdateRuntimeSettings(settingsStr));//settingsObj.mName || 
    };

    BarcodeReader.prototype.resetRuntimeSettings = function(){
        handleRetJsonString(this._instance.ResetRuntimeSettings());
    };

    BarcodeReader.prototype.outputSettingsToString = function(templateName){
        templateName = templateName || "";
        return handleRetJsonString(this._instance.OutputSettingsToString(templateName));
    };

    // String / plain object
    BarcodeReader.prototype.initRuntimeSettingsWithString = function(template, enumComflictMode){
        if(typeof template == 'string' || typeof template == 'object' && template instanceof String){ // string
        }else if(typeof template == 'object'){// object
            template = JSON.stringify(template);
        }else{ // other
            throw TypeError("'initRuntimeSettingstWithString(template, enumComflictMode)': Type of 'template' should be 'String' or 'PlainObject'.");
        }
        handleRetJsonString(this._instance.InitRuntimeSettingstWithString(template, enumComflictMode?enumComflictMode:2));
    };

    // String / plain object
    BarcodeReader.prototype.appendTplStringToRuntimeSettings = function(template, enumComflictMode){
        if(typeof template == 'string' || typeof template == 'object' && template instanceof String){ // string
        }else if(typeof template == 'object'){// object
            template = JSON.stringify(template);
        }else{ // other
            throw TypeError("'appendTplStringToRuntimeSettings(template, enumComflictMode)': Type of 'template' should be 'String' or 'PlainObject'.");
        }
        handleRetJsonString(this._instance.AppendTplStringToRuntimeSettings(template, enumComflictMode?enumComflictMode:2));
    };

    return BarcodeReader;
})();

// Barcode Format
dynamsoft.BarcodeReader.EnumBarcodeFormat = dynamsoft.BarcodeReader.EnumBarcodeFormat || (function(){
    var f = {};

    f.All = 0x1e0003ff;
    f.OneD = 0x3FF;
    f.CODE_39 = 0x1;
    f.CODE_128 = 0x2;
    f.CODE_93 = 0x4;
    f.CODABAR = 0x8;
    f.ITF = 0x10;
    f.EAN_13 = 0x20;
    f.EAN_8 = 0x40;
    f.UPC_A = 0x80;
    f.UPC_E = 0x100;
    f.INDUSTRIAL_25 = 0x200;
    f.PDF417 = 0x2000000;
    f.QR_CODE = 0x4000000;
    f.DATAMATRIX = 0x8000000;
    f.AZTEC = 0x10000000;

    return f;
})();

// Error Code
dynamsoft.BarcodeReader.EnumErrorCode = dynamsoft.BarcodeReader.EnumErrorCode || (function(){
    var e = {};
    
    e.DBR_SYSTEM_EXCEPTION = 1;
    e.DBR_SUCCESS = 0;
    e.DBR_UNKNOWN = -10000;
    e.DBR_NO_MEMORY = -10001;
    e.DBR_NULL_REFERENCE = -10002;
    e.DBR_LICENSE_INVALID = -10003;
    e.DBR_LICENSE_EXPIRED = -10004;
    e.DBR_FILE_NOT_FOUND = -10005;
    e.DBR_FILETYPE_NOT_SUPPORTED = -10006;
    e.DBR_BPP_NOT_SUPPORTED = -10007;
    e.DBR_INDEX_INVALID = -10008;
    e.DBR_BARCODE_FORMAT_INVALID = -10009;
    e.DBR_CUSTOM_REGION_INVALID = -10010;
    e.DBR_MAX_BARCODE_NUMBER_INVALID = -10011;
    e.DBR_IMAGE_READ_FAILED = -10012;
    e.DBR_TIFF_READ_FAILED = -10013;
    e.DBR_QR_LICENSE_INVALID = -10016;
    e.DBR_1D_LICENSE_INVALID = -10017;
    e.DBR_DIB_BUFFER_INVALID = -10018;
    e.DBR_PDF417_LICENSE_INVALID = 10019;
    e.DBR_DATAMATRIX_LICENSE_INVALID = -10020;
    e.DBR_PDF_READ_FAILED = -10021;
    e.DBR_PDF_DLL_MISSING = -10022;
    e.DBR_PAGE_NUMBER_INVALID = -10023;
    e.DBR_CUSTOM_SIZE_INVALID = -10024;
    e.DBR_CUSTOM_MODULESIZE_INVALID = -10025;
    e.DBR_RECOGNITION_TIMEOUT = -10026;
    e.DBR_JSON_PARSE_FAILED = -10030;
    e.DBR_JSON_TYPE_INVALID = -10031;
    e.DBR_JSON_KEY_INVALID = -10032;
    e.DBR_JSON_VALUE_INVALID = -10033;
    e.DBR_JSON_NAME_KEY_MISSING = -10034;
    e.DBR_JSON_NAME_VALUE_DUPLICATED = -10035;
    e.DBR_TEMPLATE_NAME_INVALID = -10036;
    e.DBR_JSON_NAME_REFERENCE_INVALID = -10037;
    e.DBR_PARAMETER_VALUE_INVALID = -10038;
    e.DBR_DOMAIN_NOT_MATCHED = -10039;
    e.DBR_RESERVEDINFO_NOT_MATCHED = -10040;
    e.DBR_DBRERR_AZTEC_LICENSE_INVALID = -10041;

    return e;
})();

// Image Pixel Format
dynamsoft.BarcodeReader.EnumImagePixelFormat = dynamsoft.BarcodeReader.EnumImagePixelFormat || (function(){
    var f = {};

    f.IPF_Binary = 0;
    f.IPF_BinaryInverted = 1;
    f.IPF_GrayScaled = 2;
    f.IPF_NV21 = 3;
    f.IPF_RGB_565 = 4;
    f.IPF_RGB_555 = 5;
    f.IPF_RGB_888 = 6;
    f.IPF_ARGB_8888 = 7;

    return f;
})();

// Result Type
dynamsoft.BarcodeReader.EnumResultType = dynamsoft.BarcodeReader.EnumResultType || (function(){
    var t = {};

    t.EDT_StandardText = 0;
    t.EDT_RawText = 1;
    t.EDT_CandidateText = 2;
    t.EDT_PartialText = 3;

    return t;
})();

// Terminate Stage
dynamsoft.BarcodeReader.EnumTerminateStage = dynamsoft.BarcodeReader.EnumTerminateStage || (function(){
    var t = {};

    t.ETS_Prelocalized = 0;
    t.ETS_Localized = 1;
    t.ETS_Recognized = 2;

    return t;
})();

// ConflictMode
dynamsoft.BarcodeReader.EnumConflictMode = dynamsoft.BarcodeReader.EnumConflictMode || (function(){
    var c = {};

    c.ECM_Ignore = 1;
    c.ECM_Overwrite = 2;

    return c;
})();

// BarcodeReaderException
dynamsoft.BarcodeReader.BarcodeReaderException = dynamsoft.BarcodeReader.BarcodeReaderException || (function(){
    var BarcodeReaderException = function(){
        var ag0 = arguments[0],
            ag1 = arguments[1],
            code = dynamsoft.BarcodeReader.EnumErrorCode.DBR_UNKNOWN;
        if(typeof ag0 == "number"){
            code = ag0;
            this.message = ag1;
            //Error.call(this, ag1);
        }else{
            this.message = ag0;
            //Error.call(this, ag0);
        }
        this.code = code;
    };

    var Super = function(){};
    Super.prototype = Error.prototype;
    BarcodeReaderException.prototype = new Super();
    BarcodeReaderException.prototype.constructor = BarcodeReaderException;

    return BarcodeReaderException;
})();

/* global dynamsoft, kConsoleLog*/
if(dynamsoft.BarcodeReader._jsVersion.lastIndexOf('.stable')==-1){dynamsoft.BarcodeReader._jsVersion += '.stable';}
dynamsoft.BarcodeReader.loadWasm = dynamsoft.BarcodeReader.loadWasm || function(){return new Promise(function(resolve, reject){
    var BR = dynamsoft.BarcodeReader;

    // have loaded, good!
    if('loaded' == BR._loadWasmStatus){
        return resolve();
    }
    // a task queue for multiple load task
    BR._loadWasmTaskQueue = BR._loadWasmTaskQueue || (function(){
        var t = new dynamsoft.TaskQueue();
        t.timeout = 0;
        return t;
    })();
    BR._loadWasmTaskQueue.push(function(bWasmLoadingWhenPush){
        if('loaded' == BR._loadWasmStatus){
            BR._loadWasmTaskQueue.next();
            return resolve();
        }else if(bWasmLoadingWhenPush){
            BR._loadWasmTaskQueue.next();
            return reject(BR._loadWasmStatus);
        }else{ // need load in this task
            BR._loadWasmStatus = 'loading';
            // inner load promise
            return new Promise(function(resolve, reject){

                //pre define constructor
                BR._BarcodeReaderWasm = function(){
                    throw Error("'Constructor BarcodeReader(licenseKey)': The wasm hasn't finish loading.");
                };

                var bWasmValid = !!self.WebAssembly && !(
                    /Safari/.test(navigator.userAgent) && 
                    !/Chrome/.test(navigator.userAgent) && 
                    /\(.+\s11_2_([2-6]).*\)/.test(navigator.userAgent));
                if(!bWasmValid){
                    return reject("'Constructor BarcodeReader(licenseKey)': The browser doesn't support Webassembly.");
                }

                var kInstantiateCachedURL = function(version, url, importObject) {
                    if(self.kConsoleLog){kConsoleLog('start handle dbr wasm, version: ' + version);}
                    var startHandleDbrWasmTime = new Date().getTime();

                    const dbName = 'dynamsoft';
                    const storeName = 'wasm';
                    const wasmKey = 'dbr-' + version;
                    //var db = undefined;

                    var openDb = ()=>{
                        return new Promise((resolve, reject)=>{
                            var request = indexedDB.open(dbName,1);
                            request.onupgradeneeded = () => { request.result.createObjectStore(storeName); };
                            request.onsuccess = () => { resolve(request.result); };
                            request.onerror = () => {
                                var errStr = request.error.message || request.error;
                                if(errStr.indexOf("version") != -1){
                                    request = indexedDB.deleteDatabase(dbName);
                                    request.onsuccess = () => {
                                        var request = indexedDB.open(dbName,1);
                                        request.onupgradeneeded = () => { request.result.createObjectStore(storeName); };
                                        request.onsuccess = () => { resolve(request.result); };
                                        request.onerror = () => {reject('open db ['+dbName+'] fail');};
                                    };
                                    request.onerror = () => {reject('delete db ['+dbName+'] fail');};
                                }else{
                                    reject('open db ['+dbName+'] fail: '+errStr);
                                }
                            };
                        });
                    };

                    var testIfSupportStoreModuleInDb = function(db){
                        var bSupportStoreModuleInDb_Key = 'bSupportStoreModuleInDb';
                        return new Promise((resolve, reject)=>{
                            var storeReadonly = db.transaction([storeName]).objectStore(storeName);//, 'readwrite'
                            var request = storeReadonly.get(bSupportStoreModuleInDb_Key);

                            var tryStoreModule = ()=>{
                                var store = db.transaction([storeName], 'readwrite').objectStore(storeName);
                                var bytes = new Uint8Array([
                                    0x00,0x61,0x73,0x6d, 0x01,0x00,0x00,0x00, 0x01,0x07,0x01,0x60, 0x02,0x7f,0x7f,0x01,
                                    0x7f,0x03,0x02,0x01, 0x00,0x07,0x07,0x01, 0x03,0x58,0x4f,0x52, 0x00,0x00,0x0a,0x09,
                                    0x01,0x07,0x00,0x20, 0x00,0x20,0x01,0x73, 0x0b,0x00,0x1a,0x04, 0x6e,0x61,0x6d,0x65,
                                    0x01,0x0a,0x0a,0x00, 0x07,0x57,0x61,0x73, 0x6d,0x58,0x4f,0x52, 0x02,0x07,0x01,0x00,
                                    0x02,0x00,0x00,0x01, 0x00
                                ]);
                                try{
                                    var request = store.put(new WebAssembly.Module(bytes.buffer), 'testStoreModule');
                                    request.onsuccess = () => { 
                                        var request = store.put(true, bSupportStoreModuleInDb_Key);
                                        request.onsuccess = function(){
                                            resolve('set bSupportStoreModuleInDb = true success');
                                        };
                                        request.onerror = function(){
                                            reject('set bSupportStoreModuleInDb = true fail');
                                        };
                                    };
                                    request.onerror = () => { 
                                        reject('Failed to store [testStoreModule] in wasm cache, bSupportStoreModuleInDb == false: '+(request.error.message || request.error));
                                    };
                                }catch(ex){
                                    return reject('Failed to store [testStoreModule] in wasm cache, bSupportStoreModuleInDb == false: '+(ex.message || ex));
                                }
                            };

                            request.onsuccess = ()=>{
                                if(request.result){
                                    resolve('bSupportStoreModuleInDb == true');
                                }else{
                                    tryStoreModule();
                                }
                            };
                            request.onerror = tryStoreModule;
                        });
                    };
                
                    var lookupInDatabase = (db)=> {
                        return new Promise((resolve, reject) => {
                            var store = db.transaction([storeName]).objectStore(storeName);
                            var request = store.get(wasmKey);
                            request.onerror = reject.bind(null, 'Error getting wasm '+wasmKey);
                            request.onsuccess = () => {
                                if (request.result)
                                    resolve(request.result);
                                else
                                    reject(wasmKey+' was not found in wasm cache');
                            };
                        });
                    };
                
                    var storeInDatabase = (db, data) => {
                        return new Promise((resolve, reject)=>{
                            var store = db.transaction([storeName], 'readwrite').objectStore(storeName);
                            var request = store.put(data, wasmKey);
                            request.onerror = () => { 
                                reject('Failed to store '+wasmKey+' in wasm cache: '+(request.error.message||request.error));
                            };
                            request.onsuccess = () => { 
                                resolve('Successfully stored '+wasmKey+' in wasm cache');
                            };
                        });
                    };

                    return openDb().then(db=>{
                        //test If SupportStoreModuleInDb
                        if(self.kConsoleLog){kConsoleLog('open db success');}
                        return testIfSupportStoreModuleInDb(db).then(info=>{
                            if(self.kConsoleLog){kConsoleLog(info);}
                            return Promise.resolve([db, true]);
                        }).catch(ex=>{
                            if(self.kConsoleLog){kConsoleLog(ex.message || ex);}
                            return Promise.resolve([db, false]);
                        });
                    }).then((dbInfoArr)=>{
                        // get [module,instance] and store in db
                        var db = dbInfoArr[0], bSupportStoreModuleInDb = dbInfoArr[1];
                        var startOpenDbTime = new Date().getTime();
                        return lookupInDatabase(db).then(wasm=>{
                            // get stored
                            if(wasm instanceof WebAssembly.Module){
                                // get a module
                                if(self.kConsoleLog){kConsoleLog('get a wasm module from db, timecost:'+(new Date().getTime() - startOpenDbTime));}
                                let startBuildTime = new Date().getTime();
                                return WebAssembly.instantiate(wasm, importObject).then(instance=>{
                                    if(self.kConsoleLog){kConsoleLog('build instance from module timecost: '+(new Date().getTime() - startBuildTime));}
                                    if(self.kConsoleLog){kConsoleLog('finish handle dbr wasm, total timecost: '+(new Date().getTime() - startHandleDbrWasmTime));}
                                    return Promise.resolve({module:wasm, instance:instance});
                                });
                            }else{
                                // get a binary
                                if(self.kConsoleLog){kConsoleLog('get a wasm binary from db, timecost:'+(new Date().getTime() - startOpenDbTime));}
                                let startBuildTime = new Date().getTime();
                                return WebAssembly.instantiate(wasm, importObject).then(result=>{
                                    if(self.kConsoleLog){kConsoleLog('build instance from binary timecost: '+(new Date().getTime() - startBuildTime));}
                                    if(bSupportStoreModuleInDb){
                                        // store module
                                        var startStoreTime = new Date().getTime();
                                        return storeInDatabase(db, result.module).then(info=>{
                                            if(self.kConsoleLog){kConsoleLog(info+', timecost: '+(new Date().getTime() - startStoreTime));}
                                            if(self.kConsoleLog){kConsoleLog('finish handle dbr wasm, total timecost: '+(new Date().getTime() - startHandleDbrWasmTime));}
                                            return Promise.resolve(result);
                                        });
                                    }else{
                                        if(self.kConsoleLog){kConsoleLog('finish handle dbr wasm, total timecost: '+(new Date().getTime() - startHandleDbrWasmTime));}
                                        return Promise.resolve(result);
                                    }
                                });
                            }
                        }, ex=>{
                            //get from url
                            if(self.kConsoleLog){kConsoleLog(ex.message || ex);}
                            var startDownloadTime = new Date().getTime();
                            if(bSupportStoreModuleInDb){
                                return WebAssembly.instantiateStreaming(fetch(url), importObject).then(results => {
                                    if(self.kConsoleLog){kConsoleLog('download with build timecost: '+(new Date().getTime() - startDownloadTime));}
                                    // store module
                                    let startStoreTime = new Date().getTime();
                                    return storeInDatabase(db, results.module).then(info=>{
                                        if(self.kConsoleLog){kConsoleLog(info+', timecost: '+(new Date().getTime() - startStoreTime));}
                                        if(self.kConsoleLog){kConsoleLog('finish handle dbr wasm, total timecost: '+(new Date().getTime() - startHandleDbrWasmTime));}
                                        return Promise.resolve(results);
                                    });
                                });
                            }else{
                                return fetch(url).then(response=>{
                                    if(self.kConsoleLog){kConsoleLog('download timecost: '+(new Date().getTime() - startDownloadTime));}
                                    return response.arrayBuffer();
                                }).then(arrayBuffer=>{
                                    //store binary
                                    let startStoreTime = new Date().getTime();
                                    return storeInDatabase(db, arrayBuffer).then(info=>{
                                        if(self.kConsoleLog){kConsoleLog(info+', timecost: '+(new Date().getTime() - startStoreTime));}
                                        return Promise.resolve(arrayBuffer);
                                    });
                                }).then(arrayBuffer=>{
                                    var startBuildTime = new Date().getTime();
                                    return WebAssembly.instantiate(arrayBuffer, importObject).then(result=>{
                                        if(self.kConsoleLog){kConsoleLog('build instance from binary timecost: '+(new Date().getTime() - startBuildTime));}
                                        if(self.kConsoleLog){kConsoleLog('finish handle dbr wasm, total timecost: '+(new Date().getTime() - startHandleDbrWasmTime));}
                                        return Promise.resolve(result);
                                    });
                                });
                            }
                        });
                    }).catch(ex=>{
                        // not use indexedDB
                        if(self.kConsoleLog){kConsoleLog(ex.message || ex);}
                        if(WebAssembly.instantiateStreaming){
                            return WebAssembly.instantiateStreaming(fetch(url), importObject).then(results => {
                                if(self.kConsoleLog){kConsoleLog('finish handle dbr wasm, total timecost: '+(new Date().getTime() - startHandleDbrWasmTime));}
                                return Promise.resolve(results);
                            });
                        }else{
                            return fetch(url).then(response=>{
                                return response.arrayBuffer();
                            }).then(arrayBuffer=>{
                                return WebAssembly.instantiate(arrayBuffer, importObject).then(result=>{
                                    if(self.kConsoleLog){kConsoleLog('finish handle dbr wasm, total timecost: '+(new Date().getTime() - startHandleDbrWasmTime));}
                                    return Promise.resolve(result);
                                });
                            });
                        }
                    });
                };

                var Module = {};
                Module.locateFile = function(){
                    var wasmName = "dbr-"+BR._jsVersion+".wasm";
                    if(dynamsoft.dbrEnv.resourcesPath){
                        var path = dynamsoft.dbrEnv.resourcesPath;
                        if(path.charAt(path.length - 1) != '/'){
                            path += '/';
                        }
                        return path + wasmName;
                    }else{
                        return wasmName;
                    }
                };
                Module.onRuntimeInitialized = function(){
                    BR._BarcodeReaderWasm = Module.BarcodeReaderWasm;
                    BR._loadWasmStatus = "loaded";
                    BR.version = (new Module.BarcodeReaderWasm("")).GetVersion() + "(JS " + BR._jsVersion + '.' + BR._jsEditVersion + ")";
                    resolve();
                };
                Module.onExit = Module.onAbort = function(status){
                    BR._BarcodeReaderWasm = function(){
                        throw Error("'Constructor BarcodeReader(licenseKey)': The wasm load failed. Status: " + status);
                    };
                    reject(status);
                };
                /* eslint-disable */
var c;c||(c=typeof Module !== 'undefined' ? Module : {});var aa={},n;for(n in c)c.hasOwnProperty(n)&&(aa[n]=c[n]);c.arguments=[];c.thisProgram="./this.program";c.quit=function(a,b){throw b;};c.preRun=[];c.postRun=[];var ba=!1,q=!1,r=!1,ca=!1;
if(c.ENVIRONMENT)if("WEB"===c.ENVIRONMENT)ba=!0;else if("WORKER"===c.ENVIRONMENT)q=!0;else if("NODE"===c.ENVIRONMENT)r=!0;else if("SHELL"===c.ENVIRONMENT)ca=!0;else throw Error("Module['ENVIRONMENT'] value is not valid. must be one of: WEB|WORKER|NODE|SHELL.");else ba="object"===typeof window,q="function"===typeof importScripts,r="object"===typeof process&&"function"===typeof require&&!ba&&!q,ca=!ba&&!r&&!q;
if(r){var da,ea;c.read=function(a,b){da||(da=require("fs"));ea||(ea=require("path"));a=ea.normalize(a);a=da.readFileSync(a);return b?a:a.toString()};c.readBinary=function(a){a=c.read(a,!0);a.buffer||(a=new Uint8Array(a));assert(a.buffer);return a};1<process.argv.length&&(c.thisProgram=process.argv[1].replace(/\\/g,"/"));c.arguments=process.argv.slice(2);"undefined"!==typeof module&&(module.exports=c);process.on("uncaughtException",function(a){if(!(a instanceof fa))throw a;});process.on("unhandledRejection",
function(){process.exit(1)});c.inspect=function(){return"[Emscripten Module object]"}}else if(ca)"undefined"!=typeof read&&(c.read=function(a){return read(a)}),c.readBinary=function(a){if("function"===typeof readbuffer)return new Uint8Array(readbuffer(a));a=read(a,"binary");assert("object"===typeof a);return a},"undefined"!=typeof scriptArgs?c.arguments=scriptArgs:"undefined"!=typeof arguments&&(c.arguments=arguments),"function"===typeof quit&&(c.quit=function(a){quit(a)});else if(ba||q)c.read=function(a){var b=
new XMLHttpRequest;b.open("GET",a,!1);b.send(null);return b.responseText},q&&(c.readBinary=function(a){var b=new XMLHttpRequest;b.open("GET",a,!1);b.responseType="arraybuffer";b.send(null);return new Uint8Array(b.response)}),c.readAsync=function(a,b,d){var e=new XMLHttpRequest;e.open("GET",a,!0);e.responseType="arraybuffer";e.onload=function(){200==e.status||0==e.status&&e.response?b(e.response):d()};e.onerror=d;e.send(null)},c.setWindowTitle=function(a){document.title=a};
c.print="undefined"!==typeof console?console.log.bind(console):"undefined"!==typeof print?print:null;c.printErr="undefined"!==typeof printErr?printErr:"undefined"!==typeof console&&console.warn.bind(console)||c.print;c.print=c.print;c.printErr=c.printErr;for(n in aa)aa.hasOwnProperty(n)&&(c[n]=aa[n]);aa=void 0;function ia(a){assert(!la);var b=u;u=u+a+15&-16;return b}function ma(a){assert(y);var b=z[y>>2];a=b+a+15&-16;z[y>>2]=a;return a>=A&&!na()?(z[y>>2]=b,0):b}
function oa(a){var b;b||(b=16);return Math.ceil(a/b)*b}var pa=0;function assert(a,b){a||B("Assertion failed: "+b)}function qa(a,b){if("number"===typeof a){var d=!0;var e=a}else d=!1,e=a.length;b=4==b?f:["function"===typeof C?C:ia,ra,ia,ma][void 0===b?2:b](Math.max(e,1));if(d){var f=b;assert(0==(b&3));for(a=b+(e&-4);f<a;f+=4)z[f>>2]=0;for(a=b+e;f<a;)D[f++>>0]=0;return b}a.subarray||a.slice?E.set(a,b):E.set(new Uint8Array(a),b);return b}
function F(a){var b;if(0===b||!a)return"";for(var d=0,e,f=0;;){e=E[a+f>>0];d|=e;if(0==e&&!b)break;f++;if(b&&f==b)break}b||(b=f);e="";if(128>d){for(;0<b;)d=String.fromCharCode.apply(String,E.subarray(a,a+Math.min(b,1024))),e=e?e+d:d,a+=1024,b-=1024;return e}return sa(E,a)}var ta="undefined"!==typeof TextDecoder?new TextDecoder("utf8"):void 0;
function sa(a,b){for(var d=b;a[d];)++d;if(16<d-b&&a.subarray&&ta)return ta.decode(a.subarray(b,d));for(d="";;){var e=a[b++];if(!e)return d;if(e&128){var f=a[b++]&63;if(192==(e&224))d+=String.fromCharCode((e&31)<<6|f);else{var g=a[b++]&63;if(224==(e&240))e=(e&15)<<12|f<<6|g;else{var h=a[b++]&63;if(240==(e&248))e=(e&7)<<18|f<<12|g<<6|h;else{var k=a[b++]&63;if(248==(e&252))e=(e&3)<<24|f<<18|g<<12|h<<6|k;else{var l=a[b++]&63;e=(e&1)<<30|f<<24|g<<18|h<<12|k<<6|l}}}65536>e?d+=String.fromCharCode(e):(e-=
65536,d+=String.fromCharCode(55296|e>>10,56320|e&1023))}}else d+=String.fromCharCode(e)}}
function va(a,b,d,e){if(!(0<e))return 0;var f=d;e=d+e-1;for(var g=0;g<a.length;++g){var h=a.charCodeAt(g);55296<=h&&57343>=h&&(h=65536+((h&1023)<<10)|a.charCodeAt(++g)&1023);if(127>=h){if(d>=e)break;b[d++]=h}else{if(2047>=h){if(d+1>=e)break;b[d++]=192|h>>6}else{if(65535>=h){if(d+2>=e)break;b[d++]=224|h>>12}else{if(2097151>=h){if(d+3>=e)break;b[d++]=240|h>>18}else{if(67108863>=h){if(d+4>=e)break;b[d++]=248|h>>24}else{if(d+5>=e)break;b[d++]=252|h>>30;b[d++]=128|h>>24&63}b[d++]=128|h>>18&63}b[d++]=128|
h>>12&63}b[d++]=128|h>>6&63}b[d++]=128|h&63}}b[d]=0;return d-f}function wa(a){for(var b=0,d=0;d<a.length;++d){var e=a.charCodeAt(d);55296<=e&&57343>=e&&(e=65536+((e&1023)<<10)|a.charCodeAt(++d)&1023);127>=e?++b:b=2047>=e?b+2:65535>=e?b+3:2097151>=e?b+4:67108863>=e?b+5:b+6}return b}"undefined"!==typeof TextDecoder&&new TextDecoder("utf-16le");var xa=65536,ya=16777216,za=16777216;function Aa(a,b){0<a%b&&(a+=b-a%b);return a}var buffer,D,E,Ba,Ca,z,I,Da,Ea;
function Fa(){c.HEAP8=D=new Int8Array(buffer);c.HEAP16=Ba=new Int16Array(buffer);c.HEAP32=z=new Int32Array(buffer);c.HEAPU8=E=new Uint8Array(buffer);c.HEAPU16=Ca=new Uint16Array(buffer);c.HEAPU32=I=new Uint32Array(buffer);c.HEAPF32=Da=new Float32Array(buffer);c.HEAPF64=Ea=new Float64Array(buffer)}var Ga,u,la,Ha,Ia,Ja,Ka,y;Ga=u=Ha=Ia=Ja=Ka=y=0;la=!1;
c.reallocBuffer||(c.reallocBuffer=function(a){try{if(ArrayBuffer.yb)var b=ArrayBuffer.yb(buffer,a);else{var d=D;b=new ArrayBuffer(a);(new Int8Array(b)).set(d)}}catch(e){return!1}return La(b)?b:!1});function na(){var a=c.usingWasm?xa:ya,b=2147483648-a;if(z[y>>2]>b)return!1;var d=A;for(A=Math.max(A,za);A<z[y>>2];)536870912>=A?A=Aa(2*A,a):A=Math.min(Aa((3*A+2147483648)/4,a),b);a=c.reallocBuffer(A);if(!a||a.byteLength!=A)return A=d,!1;c.buffer=buffer=a;Fa();return!0}var Ma;
try{Ma=Function.prototype.call.bind(Object.getOwnPropertyDescriptor(ArrayBuffer.prototype,"byteLength").get),Ma(new ArrayBuffer(4))}catch(a){Ma=function(b){return b.byteLength}}var Na=c.TOTAL_STACK||5242880,A=c.TOTAL_MEMORY||16777216;A<Na&&c.printErr("TOTAL_MEMORY should be larger than TOTAL_STACK, was "+A+"! (TOTAL_STACK="+Na+")");
c.buffer?buffer=c.buffer:("object"===typeof WebAssembly&&"function"===typeof WebAssembly.Memory?(c.wasmMemory=new WebAssembly.Memory({initial:A/xa}),buffer=c.wasmMemory.buffer):buffer=new ArrayBuffer(A),c.buffer=buffer);Fa();z[0]=1668509029;Ba[1]=25459;if(115!==E[2]||99!==E[3])throw"Runtime error: expected the system to be little-endian!";
function Oa(a){for(;0<a.length;){var b=a.shift();if("function"==typeof b)b();else{var d=b.b;"number"===typeof d?void 0===b.ua?c.dynCall_v(d):c.dynCall_vi(d,b.ua):d(void 0===b.ua?null:b.ua)}}}var Pa=[],Qa=[],Ra=[],Sa=[],Ta=[],Ua=!1;function Va(){var a=c.preRun.shift();Pa.unshift(a)}var Wa=0,Xa=null,Ya=null;c.preloadedImages={};c.preloadedAudios={};
function Za(a){return String.prototype.startsWith?a.startsWith("data:application/octet-stream;base64,"):0===a.indexOf("data:application/octet-stream;base64,")}
(function(){function a(){try{if(c.wasmBinary)return new Uint8Array(c.wasmBinary);if(c.readBinary)return c.readBinary(f);throw"on the web, we need the wasm binary to be preloaded and set on Module['wasmBinary']. emcc.py will do that for you when generating HTML (but not JS)";}catch(p){B(p)}}function b(){return c.wasmBinary||!ba&&!q||"function"!==typeof fetch?new Promise(function(b){b(a())}):fetch(f,{credentials:"same-origin"}).then(function(a){if(!a.ok)throw"failed to load wasm binary file at '"+f+
"'";return a.arrayBuffer()}).catch(function(){return a()})}function d(a){function d(a){k=a.exports;if(k.memory){a=k.memory;var b=c.buffer;a.byteLength<b.byteLength&&c.printErr("the new buffer in mergeMemory is smaller than the previous one. in native wasm, we should grow memory here");b=new Int8Array(b);(new Int8Array(a)).set(b);c.buffer=buffer=a;Fa()}c.asm=k;c.usingWasm=!0;Wa--;c.monitorRunDependencies&&c.monitorRunDependencies(Wa);0==Wa&&(null!==Xa&&(clearInterval(Xa),Xa=null),Ya&&(a=Ya,Ya=null,
a()))}function e(a){d(a.instance)}function g(a){b().then(function(a){return WebAssembly.instantiate(a,h)}).then(a).catch(function(a){c.printErr("failed to asynchronously prepare wasm: "+a);B(a)})}if("object"!==typeof WebAssembly)return c.printErr("no native wasm support detected"),!1;if(!(c.wasmMemory instanceof WebAssembly.Memory))return c.printErr("no native wasm Memory in use"),!1;a.memory=c.wasmMemory;h.global={NaN:NaN,Infinity:Infinity};h["global.Math"]=Math;h.env=a;Wa++;c.monitorRunDependencies&&
c.monitorRunDependencies(Wa);if(c.instantiateWasm)try{return c.instantiateWasm(h,d)}catch(x){return c.printErr("Module.instantiateWasm callback failed with error: "+x),!1}c.wasmBinary||Za(f)||"function"!==typeof fetch?g(e):kInstantiateCachedURL(BR._jsVersion,f,h).then(e).catch(function(a){c.printErr("wasm streaming compile failed: "+a);c.printErr("falling back to ArrayBuffer instantiation");g(e)});return{}}var e=
"dbr.min.wast",f="dbr.min.wasm",g="dbr.min.temp.asm.js";"function"===typeof c.locateFile&&(Za(e)||(e=c.locateFile(e)),Za(f)||(f=c.locateFile(f)),Za(g)||(g=c.locateFile(g)));var h={global:null,env:null,asm2wasm:{"f64-rem":function(a,b){return a%b},"debugger":function(){debugger}},parent:c},k=null;c.asmPreload=c.asm;var l=c.reallocBuffer;c.reallocBuffer=function(a){if("asmjs"===m)var b=l(a);else a:{a=Aa(a,c.usingWasm?xa:ya);var d=c.buffer.byteLength;if(c.usingWasm)try{b=-1!==c.wasmMemory.grow((a-d)/
65536)?c.buffer=c.wasmMemory.buffer:null;break a}catch(w){b=null;break a}b=void 0}return b};var m="";c.asm=function(a,b){if(!b.table){a=c.wasmTableSize;void 0===a&&(a=1024);var e=c.wasmMaxTableSize;b.table="object"===typeof WebAssembly&&"function"===typeof WebAssembly.Table?void 0!==e?new WebAssembly.Table({initial:a,maximum:e,element:"anyfunc"}):new WebAssembly.Table({initial:a,element:"anyfunc"}):Array(a);c.wasmTable=b.table}b.memoryBase||(b.memoryBase=c.STATIC_BASE);b.tableBase||(b.tableBase=0);
(b=d(b))||B("no binaryen method succeeded. consider enabling more options, like interpreting, if you want that: https://github.com/kripken/emscripten/wiki/WebAssembly#binaryen-methods");return b}})();Ga=1024;u=Ga+897344;
Qa.push({b:function(){$a()}},{b:function(){ab()}},{b:function(){bb()}},{b:function(){cb()}},{b:function(){db()}},{b:function(){eb()}},{b:function(){fb()}},{b:function(){gb()}},{b:function(){hb()}},{b:function(){ib()}},{b:function(){jb()}},{b:function(){kb()}},{b:function(){lb()}},{b:function(){mb()}},{b:function(){nb()}},{b:function(){ob()}},{b:function(){pb()}},{b:function(){qb()}},{b:function(){rb()}},{b:function(){sb()}},{b:function(){tb()}},{b:function(){ub()}},{b:function(){vb()}},{b:function(){wb()}},
{b:function(){xb()}},{b:function(){yb()}},{b:function(){zb()}},{b:function(){Ab()}},{b:function(){Bb()}},{b:function(){Cb()}},{b:function(){Db()}},{b:function(){Eb()}},{b:function(){Fb()}},{b:function(){Gb()}},{b:function(){Hb()}},{b:function(){Ib()}},{b:function(){Jb()}},{b:function(){Kb()}},{b:function(){Lb()}},{b:function(){Mb()}},{b:function(){Nb()}},{b:function(){Ob()}},{b:function(){Pb()}},{b:function(){Qb()}},{b:function(){Rb()}},{b:function(){Sb()}},{b:function(){Tb()}},{b:function(){Ub()}},
{b:function(){Vb()}},{b:function(){Wb()}},{b:function(){Xb()}},{b:function(){Yb()}},{b:function(){Zb()}},{b:function(){$b()}},{b:function(){ac()}},{b:function(){bc()}},{b:function(){cc()}},{b:function(){dc()}},{b:function(){ec()}},{b:function(){fc()}},{b:function(){hc()}},{b:function(){ic()}},{b:function(){jc()}},{b:function(){kc()}},{b:function(){lc()}},{b:function(){mc()}},{b:function(){nc()}},{b:function(){oc()}},{b:function(){pc()}},{b:function(){qc()}},{b:function(){rc()}},{b:function(){sc()}},
{b:function(){tc()}});c.STATIC_BASE=Ga;c.STATIC_BUMP=897344;u+=16;function uc(){return!!uc.u}var vc=0,wc=[],J={};function xc(a){if(!a||J[a])return a;for(var b in J)if(J[b].Ia===a)return b;return a}function ___cxa_free_exception(a){try{return K(a)}catch(b){}}
function yc(){var a=vc;if(!a)return(zc(0),0)|0;var b=J[a],d=b.type;if(!d)return(zc(0),a)|0;var e=Array.prototype.slice.call(arguments);c.___cxa_is_pointer_type(d);Ac||(Ac=C(4));z[Ac>>2]=a;a=Ac;for(var f=0;f<e.length;f++)if(e[f]&&c.___cxa_can_catch(e[f],d,a))return a=z[a>>2],b.Ia=a,(zc(e[f]),a)|0;a=z[a>>2];return(zc(d),a)|0}
var Ac,L={Y:1,L:2,md:3,hc:4,fa:5,Ha:6,Ab:7,Fc:8,ea:9,Ob:10,Ca:11,wd:11,Ya:12,ra:13,$b:14,Rc:15,Da:16,Ea:17,xd:18,ta:19,Fa:20,ga:21,m:22,Ac:23,Xa:24,T:25,td:26,ac:27,Nc:28,ha:29,jd:30,tc:31,ad:32,Xb:33,ed:34,Jc:42,dc:43,Pb:44,kc:45,lc:46,mc:47,sc:48,ud:49,Dc:50,jc:51,Ub:35,Gc:37,Gb:52,Jb:53,yd:54,Bc:55,Kb:56,Lb:57,Vb:35,Mb:59,Pc:60,Ec:61,qd:62,Oc:63,Kc:64,Lc:65,hd:66,Hc:67,Db:68,nd:69,Qb:70,bd:71,vc:72,Yb:73,Ib:74,Wc:76,Hb:77,gd:78,nc:79,oc:80,rc:81,qc:82,pc:83,Qc:38,Ga:39,wc:36,sa:40,Xc:95,$c:96,
Tb:104,Cc:105,Eb:97,dd:91,Uc:88,Mc:92,kd:108,Sb:111,Bb:98,Rb:103,zc:101,xc:100,rd:110,bc:112,cc:113,fc:115,Fb:114,Wb:89,uc:90,cd:93,ld:94,Cb:99,yc:102,ic:106,Sc:107,sd:109,vd:87,Zb:122,od:116,Vc:95,Ic:123,ec:84,Yc:75,Nb:125,Tc:131,Zc:130,pd:86};function Bc(a){c.___errno_location&&(z[c.___errno_location()>>2]=a);return a}
var Cc={0:"Success",1:"Not super-user",2:"No such file or directory",3:"No such process",4:"Interrupted system call",5:"I/O error",6:"No such device or address",7:"Arg list too long",8:"Exec format error",9:"Bad file number",10:"No children",11:"No more processes",12:"Not enough core",13:"Permission denied",14:"Bad address",15:"Block device required",16:"Mount device busy",17:"File exists",18:"Cross-device link",19:"No such device",20:"Not a directory",21:"Is a directory",22:"Invalid argument",23:"Too many open files in system",
24:"Too many open files",25:"Not a typewriter",26:"Text file busy",27:"File too large",28:"No space left on device",29:"Illegal seek",30:"Read only file system",31:"Too many links",32:"Broken pipe",33:"Math arg out of domain of func",34:"Math result not representable",35:"File locking deadlock error",36:"File or path name too long",37:"No record locks available",38:"Function not implemented",39:"Directory not empty",40:"Too many symbolic links",42:"No message of desired type",43:"Identifier removed",
44:"Channel number out of range",45:"Level 2 not synchronized",46:"Level 3 halted",47:"Level 3 reset",48:"Link number out of range",49:"Protocol driver not attached",50:"No CSI structure available",51:"Level 2 halted",52:"Invalid exchange",53:"Invalid request descriptor",54:"Exchange full",55:"No anode",56:"Invalid request code",57:"Invalid slot",59:"Bad font file fmt",60:"Device not a stream",61:"No data (for no delay io)",62:"Timer expired",63:"Out of streams resources",64:"Machine is not on the network",
65:"Package not installed",66:"The object is remote",67:"The link has been severed",68:"Advertise error",69:"Srmount error",70:"Communication error on send",71:"Protocol error",72:"Multihop attempted",73:"Cross mount point (not really error)",74:"Trying to read unreadable message",75:"Value too large for defined data type",76:"Given log. name not unique",77:"f.d. invalid for this operation",78:"Remote address changed",79:"Can   access a needed shared lib",80:"Accessing a corrupted shared lib",81:".lib section in a.out corrupted",
82:"Attempting to link in too many libs",83:"Attempting to exec a shared library",84:"Illegal byte sequence",86:"Streams pipe error",87:"Too many users",88:"Socket operation on non-socket",89:"Destination address required",90:"Message too long",91:"Protocol wrong type for socket",92:"Protocol not available",93:"Unknown protocol",94:"Socket type not supported",95:"Not supported",96:"Protocol family not supported",97:"Address family not supported by protocol family",98:"Address already in use",99:"Address not available",
100:"Network interface is not configured",101:"Network is unreachable",102:"Connection reset by network",103:"Connection aborted",104:"Connection reset by peer",105:"No buffer space available",106:"Socket is already connected",107:"Socket is not connected",108:"Can't send after socket shutdown",109:"Too many references",110:"Connection timed out",111:"Connection refused",112:"Host is down",113:"Host is unreachable",114:"Socket already connected",115:"Connection already in progress",116:"Stale file handle",
122:"Quota exceeded",123:"No medium (in tape drive)",125:"Operation canceled",130:"Previous owner died",131:"State not recoverable"};function Dc(a,b){for(var d=0,e=a.length-1;0<=e;e--){var f=a[e];"."===f?a.splice(e,1):".."===f?(a.splice(e,1),d++):d&&(a.splice(e,1),d--)}if(b)for(;d;d--)a.unshift("..");return a}function Ec(a){var b="/"===a.charAt(0),d="/"===a.substr(-1);(a=Dc(a.split("/").filter(function(a){return!!a}),!b).join("/"))||b||(a=".");a&&d&&(a+="/");return(b?"/":"")+a}
function Fc(a){var b=/^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/.exec(a).slice(1);a=b[0];b=b[1];if(!a&&!b)return".";b&&(b=b.substr(0,b.length-1));return a+b}function Gc(a){if("/"===a)return"/";var b=a.lastIndexOf("/");return-1===b?a:a.substr(b+1)}function Hc(){var a=Array.prototype.slice.call(arguments,0);return Ec(a.join("/"))}function Ic(a,b){return Ec(a+"/"+b)}
function Jc(){for(var a="",b=!1,d=arguments.length-1;-1<=d&&!b;d--){b=0<=d?arguments[d]:"/";if("string"!==typeof b)throw new TypeError("Arguments to path.resolve must be strings");if(!b)return"";a=b+"/"+a;b="/"===b.charAt(0)}a=Dc(a.split("/").filter(function(a){return!!a}),!b).join("/");return(b?"/":"")+a||"."}var Kc=[];function Lc(a,b){Kc[a]={input:[],output:[],W:b};Mc(a,Nc)}
var Nc={open:function(a){var b=Kc[a.node.rdev];if(!b)throw new M(L.ta);a.tty=b;a.seekable=!1},close:function(a){a.tty.W.flush(a.tty)},flush:function(a){a.tty.W.flush(a.tty)},read:function(a,b,d,e){if(!a.tty||!a.tty.W.Sa)throw new M(L.Ha);for(var f=0,g=0;g<e;g++){try{var h=a.tty.W.Sa(a.tty)}catch(k){throw new M(L.fa);}if(void 0===h&&0===f)throw new M(L.Ca);if(null===h||void 0===h)break;f++;b[d+g]=h}f&&(a.node.timestamp=Date.now());return f},write:function(a,b,d,e){if(!a.tty||!a.tty.W.Aa)throw new M(L.Ha);
for(var f=0;f<e;f++)try{a.tty.W.Aa(a.tty,b[d+f])}catch(g){throw new M(L.fa);}e&&(a.node.timestamp=Date.now());return f}},Pc={Sa:function(a){if(!a.input.length){var b=null;if(r){var d=new Buffer(256),e=0,f=process.stdin.fd;if("win32"!=process.platform){var g=!1;try{f=fs.openSync("/dev/stdin","r"),g=!0}catch(h){}}try{e=fs.readSync(f,d,0,256,null)}catch(h){if(-1!=h.toString().indexOf("EOF"))e=0;else throw h;}g&&fs.closeSync(f);0<e?b=d.slice(0,e).toString("utf-8"):b=null}else"undefined"!=typeof window&&
"function"==typeof window.prompt?(b=window.prompt("Input: "),null!==b&&(b+="\n")):"function"==typeof readline&&(b=readline(),null!==b&&(b+="\n"));if(!b)return null;a.input=Oc(b,!0)}return a.input.shift()},Aa:function(a,b){null===b||10===b?(c.print(sa(a.output,0)),a.output=[]):0!=b&&a.output.push(b)},flush:function(a){a.output&&0<a.output.length&&(c.print(sa(a.output,0)),a.output=[])}},Qc={Aa:function(a,b){null===b||10===b?(c.printErr(sa(a.output,0)),a.output=[]):0!=b&&a.output.push(b)},flush:function(a){a.output&&
0<a.output.length&&(c.printErr(sa(a.output,0)),a.output=[])}},N={G:null,v:function(){return N.createNode(null,"/",16895,0)},createNode:function(a,b,d,e){if(24576===(d&61440)||4096===(d&61440))throw new M(L.Y);N.G||(N.G={dir:{node:{K:N.h.K,C:N.h.C,lookup:N.h.lookup,$:N.h.$,rename:N.h.rename,unlink:N.h.unlink,rmdir:N.h.rmdir,readdir:N.h.readdir,symlink:N.h.symlink},stream:{M:N.g.M}},file:{node:{K:N.h.K,C:N.h.C},stream:{M:N.g.M,read:N.g.read,write:N.g.write,Ja:N.g.Ja,Ta:N.g.Ta,na:N.g.na}},link:{node:{K:N.h.K,
C:N.h.C,readlink:N.h.readlink},stream:{}},Ma:{node:{K:N.h.K,C:N.h.C},stream:Rc}});d=Sc(a,b,d,e);16384===(d.mode&61440)?(d.h=N.G.dir.node,d.g=N.G.dir.stream,d.f={}):32768===(d.mode&61440)?(d.h=N.G.file.node,d.g=N.G.file.stream,d.l=0,d.f=null):40960===(d.mode&61440)?(d.h=N.G.link.node,d.g=N.G.link.stream):8192===(d.mode&61440)&&(d.h=N.G.Ma.node,d.g=N.G.Ma.stream);d.timestamp=Date.now();a&&(a.f[b]=d);return d},gb:function(a){if(a.f&&a.f.subarray){for(var b=[],d=0;d<a.l;++d)b.push(a.f[d]);return b}return a.f},
zd:function(a){return a.f?a.f.subarray?a.f.subarray(0,a.l):new Uint8Array(a.f):new Uint8Array},Na:function(a,b){a.f&&a.f.subarray&&b>a.f.length&&(a.f=N.gb(a),a.l=a.f.length);if(!a.f||a.f.subarray){var d=a.f?a.f.length:0;d>=b||(b=Math.max(b,d*(1048576>d?2:1.125)|0),0!=d&&(b=Math.max(b,256)),d=a.f,a.f=new Uint8Array(b),0<a.l&&a.f.set(d.subarray(0,a.l),0))}else for(!a.f&&0<b&&(a.f=[]);a.f.length<b;)a.f.push(0)},qb:function(a,b){if(a.l!=b)if(0==b)a.f=null,a.l=0;else{if(!a.f||a.f.subarray){var d=a.f;a.f=
new Uint8Array(new ArrayBuffer(b));d&&a.f.set(d.subarray(0,Math.min(b,a.l)))}else if(a.f||(a.f=[]),a.f.length>b)a.f.length=b;else for(;a.f.length<b;)a.f.push(0);a.l=b}},h:{K:function(a){var b={};b.dev=8192===(a.mode&61440)?a.id:1;b.ino=a.id;b.mode=a.mode;b.nlink=1;b.uid=0;b.gid=0;b.rdev=a.rdev;16384===(a.mode&61440)?b.size=4096:32768===(a.mode&61440)?b.size=a.l:40960===(a.mode&61440)?b.size=a.link.length:b.size=0;b.atime=new Date(a.timestamp);b.mtime=new Date(a.timestamp);b.ctime=new Date(a.timestamp);
b.O=4096;b.blocks=Math.ceil(b.size/b.O);return b},C:function(a,b){void 0!==b.mode&&(a.mode=b.mode);void 0!==b.timestamp&&(a.timestamp=b.timestamp);void 0!==b.size&&N.qb(a,b.size)},lookup:function(){throw Tc[L.L];},$:function(a,b,d,e){return N.createNode(a,b,d,e)},rename:function(a,b,d){if(16384===(a.mode&61440)){try{var e=Uc(b,d)}catch(g){}if(e)for(var f in e.f)throw new M(L.Ga);}delete a.parent.f[a.name];a.name=d;b.f[d]=a;a.parent=b},unlink:function(a,b){delete a.f[b]},rmdir:function(a,b){var d=
Uc(a,b),e;for(e in d.f)throw new M(L.Ga);delete a.f[b]},readdir:function(a){var b=[".",".."],d;for(d in a.f)a.f.hasOwnProperty(d)&&b.push(d);return b},symlink:function(a,b,d){a=N.createNode(a,b,41471,0);a.link=d;return a},readlink:function(a){if(40960!==(a.mode&61440))throw new M(L.m);return a.link}},g:{read:function(a,b,d,e,f){var g=a.node.f;if(f>=a.node.l)return 0;a=Math.min(a.node.l-f,e);assert(0<=a);if(8<a&&g.subarray)b.set(g.subarray(f,f+a),d);else for(e=0;e<a;e++)b[d+e]=g[f+e];return a},write:function(a,
b,d,e,f,g){if(!e)return 0;a=a.node;a.timestamp=Date.now();if(b.subarray&&(!a.f||a.f.subarray)){if(g)return a.f=b.subarray(d,d+e),a.l=e;if(0===a.l&&0===f)return a.f=new Uint8Array(b.subarray(d,d+e)),a.l=e;if(f+e<=a.l)return a.f.set(b.subarray(d,d+e),f),e}N.Na(a,f+e);if(a.f.subarray&&b.subarray)a.f.set(b.subarray(d,d+e),f);else for(g=0;g<e;g++)a.f[f+g]=b[d+g];a.l=Math.max(a.l,f+e);return e},M:function(a,b,d){1===d?b+=a.position:2===d&&32768===(a.node.mode&61440)&&(b+=a.node.l);if(0>b)throw new M(L.m);
return b},Ja:function(a,b,d){N.Na(a.node,b+d);a.node.l=Math.max(a.node.l,b+d)},Ta:function(a,b,d,e,f,g,h){if(32768!==(a.node.mode&61440))throw new M(L.ta);d=a.node.f;if(h&2||d.buffer!==b&&d.buffer!==b.buffer){if(0<f||f+e<a.node.l)d.subarray?d=d.subarray(f,f+e):d=Array.prototype.slice.call(d,f,f+e);a=!0;e=C(e);if(!e)throw new M(L.Ya);b.set(d,e)}else a=!1,e=d.byteOffset;return{j:e,Za:a}},na:function(a,b,d,e,f){if(32768!==(a.node.mode&61440))throw new M(L.ta);if(f&2)return 0;N.g.write(a,b,0,e,d,!1);
return 0}}},O={la:!1,tb:function(){O.la=!!process.platform.match(/^win/);var a=process.binding("constants");a.fs&&(a=a.fs);O.Oa={1024:a.O_APPEND,64:a.O_CREAT,128:a.O_EXCL,0:a.O_RDONLY,2:a.O_RDWR,4096:a.O_SYNC,512:a.O_TRUNC,1:a.O_WRONLY}},Ka:function(a){return Buffer.u?Buffer.from(a):new Buffer(a)},v:function(a){assert(r);return O.createNode(null,"/",O.Ra(a.za.root),0)},createNode:function(a,b,d){if(16384!==(d&61440)&&32768!==(d&61440)&&40960!==(d&61440))throw new M(L.m);a=Sc(a,b,d);a.h=O.h;a.g=O.g;
return a},Ra:function(a){try{var b=fs.lstatSync(a);O.la&&(b.mode=b.mode|(b.mode&292)>>2)}catch(d){if(!d.code)throw d;throw new M(L[d.code]);}return b.mode},A:function(a){for(var b=[];a.parent!==a;)b.push(a.name),a=a.parent;b.push(a.v.za.root);b.reverse();return Hc.apply(null,b)},eb:function(a){a&=-2656257;var b=0,d;for(d in O.Oa)a&d&&(b|=O.Oa[d],a^=d);if(a)throw new M(L.m);return b},h:{K:function(a){a=O.A(a);try{var b=fs.lstatSync(a)}catch(d){if(!d.code)throw d;throw new M(L[d.code]);}O.la&&!b.O&&
(b.O=4096);O.la&&!b.blocks&&(b.blocks=(b.size+b.O-1)/b.O|0);return{dev:b.dev,ino:b.ino,mode:b.mode,nlink:b.nlink,uid:b.uid,gid:b.gid,rdev:b.rdev,size:b.size,atime:b.atime,mtime:b.mtime,ctime:b.ctime,O:b.O,blocks:b.blocks}},C:function(a,b){var d=O.A(a);try{void 0!==b.mode&&(fs.chmodSync(d,b.mode),a.mode=b.mode),void 0!==b.size&&fs.truncateSync(d,b.size)}catch(e){if(!e.code)throw e;throw new M(L[e.code]);}},lookup:function(a,b){var d=Ic(O.A(a),b);d=O.Ra(d);return O.createNode(a,b,d)},$:function(a,b,
d,e){a=O.createNode(a,b,d,e);b=O.A(a);try{16384===(a.mode&61440)?fs.mkdirSync(b,a.mode):fs.writeFileSync(b,"",{mode:a.mode})}catch(f){if(!f.code)throw f;throw new M(L[f.code]);}return a},rename:function(a,b,d){a=O.A(a);b=Ic(O.A(b),d);try{fs.renameSync(a,b)}catch(e){if(!e.code)throw e;throw new M(L[e.code]);}},unlink:function(a,b){a=Ic(O.A(a),b);try{fs.unlinkSync(a)}catch(d){if(!d.code)throw d;throw new M(L[d.code]);}},rmdir:function(a,b){a=Ic(O.A(a),b);try{fs.rmdirSync(a)}catch(d){if(!d.code)throw d;
throw new M(L[d.code]);}},readdir:function(a){a=O.A(a);try{return fs.readdirSync(a)}catch(b){if(!b.code)throw b;throw new M(L[b.code]);}},symlink:function(a,b,d){a=Ic(O.A(a),b);try{fs.symlinkSync(d,a)}catch(e){if(!e.code)throw e;throw new M(L[e.code]);}},readlink:function(a){var b=O.A(a);try{return b=fs.readlinkSync(b),b=Vc.relative(Vc.resolve(a.v.za.root),b)}catch(d){if(!d.code)throw d;throw new M(L[d.code]);}}},g:{open:function(a){var b=O.A(a.node);try{32768===(a.node.mode&61440)&&(a.aa=fs.openSync(b,
O.eb(a.flags)))}catch(d){if(!d.code)throw d;throw new M(L[d.code]);}},close:function(a){try{32768===(a.node.mode&61440)&&a.aa&&fs.closeSync(a.aa)}catch(b){if(!b.code)throw b;throw new M(L[b.code]);}},read:function(a,b,d,e,f){if(0===e)return 0;try{return fs.readSync(a.aa,O.Ka(b.buffer),d,e,f)}catch(g){throw new M(L[g.code]);}},write:function(a,b,d,e,f){try{return fs.writeSync(a.aa,O.Ka(b.buffer),d,e,f)}catch(g){throw new M(L[g.code]);}},M:function(a,b,d){if(1===d)b+=a.position;else if(2===d&&32768===
(a.node.mode&61440))try{b+=fs.fstatSync(a.aa).size}catch(e){throw new M(L[e.code]);}if(0>b)throw new M(L.m);return b}}};u+=16;u+=16;u+=16;var Wc=null,Xc={},Yc=[],Zc=1,$c=null,ad=!0,bd={},M=null,Tc={};
function dd(a,b){a=Jc("/",a);b=b||{};if(!a)return{path:"",node:null};var d={Qa:!0,Ba:0},e;for(e in d)void 0===b[e]&&(b[e]=d[e]);if(8<b.Ba)throw new M(L.sa);a=Dc(a.split("/").filter(function(a){return!!a}),!1);var f=Wc;d="/";for(e=0;e<a.length;e++){var g=e===a.length-1;if(g&&b.parent)break;f=Uc(f,a[e]);d=Ic(d,a[e]);f.ma&&(!g||g&&b.Qa)&&(f=f.ma.root);if(!g||b.Pa)for(g=0;40960===(f.mode&61440);)if(f=ed(d),d=Jc(Fc(d),f),f=dd(d,{Ba:b.Ba}).node,40<g++)throw new M(L.sa);}return{path:d,node:f}}
function fd(a){for(var b;;){if(a===a.parent)return a=a.v.Ua,b?"/"!==a[a.length-1]?a+"/"+b:a+b:a;b=b?a.name+"/"+b:a.name;a=a.parent}}function gd(a,b){for(var d=0,e=0;e<b.length;e++)d=(d<<5)-d+b.charCodeAt(e)|0;return(a+d>>>0)%$c.length}function hd(a){var b=gd(a.parent.id,a.name);a.lb=$c[b];$c[b]=a}function Uc(a,b){var d;if(d=(d=id(a,"x"))?d:a.h.lookup?0:L.ra)throw new M(d,a);for(d=$c[gd(a.id,b)];d;d=d.lb){var e=d.name;if(d.parent.id===a.id&&e===b)return d}return a.h.lookup(a,b)}
function Sc(a,b,d,e){jd||(jd=function(a,b,d,e){a||(a=this);this.parent=a;this.v=a.v;this.ma=null;this.id=Zc++;this.name=b;this.mode=d;this.h={};this.g={};this.rdev=e},jd.prototype={},Object.defineProperties(jd.prototype,{read:{get:function(){return 365===(this.mode&365)},set:function(a){a?this.mode|=365:this.mode&=-366}},write:{get:function(){return 146===(this.mode&146)},set:function(a){a?this.mode|=146:this.mode&=-147}}}));a=new jd(a,b,d,e);hd(a);return a}
var kd={r:0,rs:1052672,"r+":2,w:577,wx:705,xw:705,"w+":578,"wx+":706,"xw+":706,a:1089,ax:1217,xa:1217,"a+":1090,"ax+":1218,"xa+":1218};function ld(a){var b=["r","w","rw"][a&3];a&512&&(b+="w");return b}function id(a,b){if(ad)return 0;if(-1===b.indexOf("r")||a.mode&292){if(-1!==b.indexOf("w")&&!(a.mode&146)||-1!==b.indexOf("x")&&!(a.mode&73))return L.ra}else return L.ra;return 0}function md(a,b){try{return Uc(a,b),L.Ea}catch(d){}return id(a,"wx")}
function nd(a){var b=4096;for(a=a||0;a<=b;a++)if(!Yc[a])return a;throw new M(L.Xa);}function od(a,b){pd||(pd=function(){},pd.prototype={},Object.defineProperties(pd.prototype,{object:{get:function(){return this.node},set:function(a){this.node=a}}}));var d=new pd,e;for(e in a)d[e]=a[e];a=d;b=nd(b);a.fd=b;return Yc[b]=a}var Rc={open:function(a){a.g=Xc[a.node.rdev].g;a.g.open&&a.g.open(a)},M:function(){throw new M(L.ha);}};function Mc(a,b){Xc[a]={g:b}}
function qd(a,b){var d="/"===b,e=!b;if(d&&Wc)throw new M(L.Da);if(!d&&!e){var f=dd(b,{Qa:!1});b=f.path;f=f.node;if(f.ma)throw new M(L.Da);if(16384!==(f.mode&61440))throw new M(L.Fa);}b={type:a,za:{},Ua:b,kb:[]};a=a.v(b);a.v=b;b.root=a;d?Wc=a:f&&(f.ma=b,f.v&&f.v.kb.push(b))}function rd(a,b,d){var e=dd(a,{parent:!0}).node;a=Gc(a);if(!a||"."===a||".."===a)throw new M(L.m);var f=md(e,a);if(f)throw new M(f);if(!e.h.$)throw new M(L.Y);return e.h.$(e,a,b,d)}function P(a){rd(a,16895,0)}
function sd(a,b,d){"undefined"===typeof d&&(d=b,b=438);rd(a,b|8192,d)}function td(a,b){if(!Jc(a))throw new M(L.L);var d=dd(b,{parent:!0}).node;if(!d)throw new M(L.L);b=Gc(b);var e=md(d,b);if(e)throw new M(e);if(!d.h.symlink)throw new M(L.Y);d.h.symlink(d,b,a)}function ed(a){a=dd(a).node;if(!a)throw new M(L.L);if(!a.h.readlink)throw new M(L.m);return Jc(fd(a.parent),a.h.readlink(a))}
function ud(a,b,d,e){if(""===a)throw new M(L.L);if("string"===typeof b){var f=kd[b];if("undefined"===typeof f)throw Error("Unknown file open mode: "+b);b=f}d=b&64?("undefined"===typeof d?438:d)&4095|32768:0;if("object"===typeof a)var g=a;else{a=Ec(a);try{g=dd(a,{Pa:!(b&131072)}).node}catch(k){}}f=!1;if(b&64)if(g){if(b&128)throw new M(L.Ea);}else g=rd(a,d,0),f=!0;if(!g)throw new M(L.L);8192===(g.mode&61440)&&(b&=-513);if(b&65536&&16384!==(g.mode&61440))throw new M(L.Fa);if(!f&&(d=g?40960===(g.mode&
61440)?L.sa:16384===(g.mode&61440)&&("r"!==ld(b)||b&512)?L.ga:id(g,ld(b)):L.L))throw new M(d);if(b&512){d=g;var h;"string"===typeof d?h=dd(d,{Pa:!0}).node:h=d;if(!h.h.C)throw new M(L.Y);if(16384===(h.mode&61440))throw new M(L.ga);if(32768!==(h.mode&61440))throw new M(L.m);if(d=id(h,"w"))throw new M(d);h.h.C(h,{size:0,timestamp:Date.now()})}b&=-641;e=od({node:g,path:fd(g),flags:b,seekable:!0,position:0,g:g.g,zb:[],error:!1},e);e.g.open&&e.g.open(e);!c.logReadFiles||b&1||(vd||(vd={}),a in vd||(vd[a]=
1,c.printErr("read file: "+a)));try{bd.onOpenFile&&(g=0,1!==(b&2097155)&&(g|=1),0!==(b&2097155)&&(g|=2),bd.onOpenFile(a,g))}catch(k){console.log("FS.trackingDelegate['onOpenFile']('"+a+"', flags) threw an exception: "+k.message)}return e}function wd(a){a.wa&&(a.wa=null);try{a.g.close&&a.g.close(a)}catch(b){throw b;}finally{Yc[a.fd]=null}}function xd(a,b,d){if(!a.seekable||!a.g.M)throw new M(L.ha);a.position=a.g.M(a,b,d);a.zb=[]}
function yd(){M||(M=function(a,b){this.node=b;this.rb=function(a){this.J=a;for(var b in L)if(L[b]===a){this.code=b;break}};this.rb(a);this.message=Cc[a];this.stack&&Object.defineProperty(this,"stack",{value:Error().stack,writable:!0})},M.prototype=Error(),M.prototype.constructor=M,[L.L].forEach(function(a){Tc[a]=new M(a);Tc[a].stack="<generic error, no stack>"}))}var zd;function Ad(a,b){var d=0;a&&(d|=365);b&&(d|=146);return d}
function Bd(a,b,d){a=Ic("/dev",a);var e=Ad(!!b,!!d);Cd||(Cd=64);var f=Cd++<<8|0;Mc(f,{open:function(a){a.seekable=!1},close:function(){d&&d.buffer&&d.buffer.length&&d(10)},read:function(a,d,e,f){for(var g=0,h=0;h<f;h++){try{var k=b()}catch(v){throw new M(L.fa);}if(void 0===k&&0===g)throw new M(L.Ca);if(null===k||void 0===k)break;g++;d[e+h]=k}g&&(a.node.timestamp=Date.now());return g},write:function(a,b,e,f){for(var g=0;g<f;g++)try{d(b[e+g])}catch(p){throw new M(L.fa);}f&&(a.node.timestamp=Date.now());
return g}});sd(a,e,f)}var Cd,FS={},jd,pd,vd,Dd={},Q=0;function R(){Q+=4;return z[Q-4>>2]}function Ed(){var a=Yc[R()];if(!a)throw new M(L.ea);return a}function Fd(a){switch(a){case 1:return 0;case 2:return 1;case 4:return 2;case 8:return 3;default:throw new TypeError("Unknown type size: "+a);}}var Gd=void 0;function S(a){for(var b="";E[a];)b+=Gd[E[a++]];return b}var Hd={},Id={},Jd={};
function Kd(a){if(void 0===a)return"_unknown";a=a.replace(/[^a-zA-Z0-9_]/g,"$");var b=a.charCodeAt(0);return 48<=b&&57>=b?"_"+a:a}function Ld(a,b){a=Kd(a);return(new Function("body","return function "+a+'() {\n    "use strict";    return body.apply(this, arguments);\n};\n'))(b)}
function Md(a){var b=Error,d=Ld(a,function(b){this.name=a;this.message=b;b=Error(b).stack;void 0!==b&&(this.stack=this.toString()+"\n"+b.replace(/^Error(:[^\n]*)?\n/,""))});d.prototype=Object.create(b.prototype);d.prototype.constructor=d;d.prototype.toString=function(){return void 0===this.message?this.name:this.name+": "+this.message};return d}var Nd=void 0;function T(a){throw new Nd(a);}var Od=void 0;function Pd(a){throw new Od(a);}
function Qd(a,b,d){function e(b){b=d(b);b.length!==a.length&&Pd("Mismatched type converter count");for(var e=0;e<a.length;++e)U(a[e],b[e])}a.forEach(function(a){Jd[a]=b});var f=Array(b.length),g=[],h=0;b.forEach(function(a,b){Id.hasOwnProperty(a)?f[b]=Id[a]:(g.push(a),Hd.hasOwnProperty(a)||(Hd[a]=[]),Hd[a].push(function(){f[b]=Id[a];++h;h===g.length&&e(f)}))});0===g.length&&e(f)}
function U(a,b,d){d=d||{};if(!("argPackAdvance"in b))throw new TypeError("registerType registeredInstance requires argPackAdvance");var e=b.name;a||T('type "'+e+'" must have a positive integer typeid pointer');if(Id.hasOwnProperty(a)){if(d.ib)return;T("Cannot register type '"+e+"' twice")}Id[a]=b;delete Jd[a];Hd.hasOwnProperty(a)&&(b=Hd[a],delete Hd[a],b.forEach(function(a){a()}))}function Rd(a){T(a.c.o.i.name+" instance already deleted")}var Sd=void 0,Td=[];
function Ud(){for(;Td.length;){var a=Td.pop();a.c.U=!1;a["delete"]()}}function Vd(){}var Wd={};function Xd(a,b,d){if(void 0===a[b].H){var e=a[b];a[b]=function(){a[b].H.hasOwnProperty(arguments.length)||T("Function '"+d+"' called with an invalid number of arguments ("+arguments.length+") - expects one of ("+a[b].H+")!");return a[b].H[arguments.length].apply(this,arguments)};a[b].H=[];a[b].H[e.ia]=e}}
function Yd(a,b){c.hasOwnProperty(a)?(T("Cannot register public name '"+a+"' twice"),Xd(c,a,a),c.hasOwnProperty(void 0)&&T("Cannot register multiple overloads of a function with the same number of arguments (undefined)!"),c[a].H[void 0]=b):c[a]=b}function Zd(a,b,d,e,f,g,h,k){this.name=a;this.constructor=b;this.V=d;this.R=e;this.F=f;this.fb=g;this.da=h;this.cb=k;this.nb=[]}
function $d(a,b,d){for(;b!==d;)b.da||T("Expected null or instance of "+d.name+", got an instance of "+b.name),a=b.da(a),b=b.F;return a}function ae(a,b){if(null===b)return this.ya&&T("null is not a valid "+this.name),0;b.c||T('Cannot pass "'+be(b)+'" as a '+this.name);b.c.j||T("Cannot pass deleted object as a pointer of type "+this.name);return $d(b.c.j,b.c.o.i,this.i)}
function ce(a,b){if(null===b){this.ya&&T("null is not a valid "+this.name);if(this.ka){var d=this.ob();null!==a&&a.push(this.R,d);return d}return 0}b.c||T('Cannot pass "'+be(b)+'" as a '+this.name);b.c.j||T("Cannot pass deleted object as a pointer of type "+this.name);!this.ja&&b.c.o.ja&&T("Cannot convert argument of type "+(b.c.D?b.c.D.name:b.c.o.name)+" to parameter type "+this.name);d=$d(b.c.j,b.c.o.i,this.i);if(this.ka)switch(void 0===b.c.B&&T("Passing raw pointer to smart pointer is illegal"),
this.sb){case 0:b.c.D===this?d=b.c.B:T("Cannot convert argument of type "+(b.c.D?b.c.D.name:b.c.o.name)+" to parameter type "+this.name);break;case 1:d=b.c.B;break;case 2:if(b.c.D===this)d=b.c.B;else{var e=b.clone();d=this.pb(d,de(function(){e["delete"]()}));null!==a&&a.push(this.R,d)}break;default:T("Unsupporting sharing policy")}return d}
function ee(a,b){if(null===b)return this.ya&&T("null is not a valid "+this.name),0;b.c||T('Cannot pass "'+be(b)+'" as a '+this.name);b.c.j||T("Cannot pass deleted object as a pointer of type "+this.name);b.c.o.ja&&T("Cannot convert argument of type "+b.c.o.name+" to parameter type "+this.name);return $d(b.c.j,b.c.o.i,this.i)}function fe(a){return this.fromWireType(I[a>>2])}function ge(a,b,d){if(b===d)return a;if(void 0===d.F)return null;a=ge(a,b,d.F);return null===a?null:d.cb(a)}var he={};
function ie(a,b){for(void 0===b&&T("ptr should not be undefined");a.F;)b=a.da(b),a=a.F;return he[b]}function je(a,b){b.o&&b.j||Pd("makeClassHandle requires ptr and ptrType");!!b.D!==!!b.B&&Pd("Both smartPtrType and smartPtr must be specified");b.count={value:1};return Object.create(a,{c:{value:b}})}
function V(a,b,d,e,f,g,h,k,l,m,p){this.name=a;this.i=b;this.ya=d;this.ja=e;this.ka=f;this.mb=g;this.sb=h;this.Va=k;this.ob=l;this.pb=m;this.R=p;f||void 0!==b.F?this.toWireType=ce:(this.toWireType=e?ae:ee,this.I=null)}function ke(a,b){c.hasOwnProperty(a)||Pd("Replacing nonexistant public symbol");c[a]=b;c[a].ia=void 0}
function le(a,b){a=S(a);if(void 0!==c["FUNCTION_TABLE_"+a])var d=c["FUNCTION_TABLE_"+a][b];else if("undefined"!==typeof FUNCTION_TABLE)d=FUNCTION_TABLE[b];else{d=c.asm["dynCall_"+a];void 0===d&&(d=c.asm["dynCall_"+a.replace(/f/g,"d")],void 0===d&&T("No dynCall invoker for signature: "+a));for(var e=[],f=1;f<a.length;++f)e.push("a"+f);f="return function "+("dynCall_"+a+"_"+b)+"("+e.join(", ")+") {\n";f+="    return dynCall(rawFunction"+(e.length?", ":"")+e.join(", ")+");\n";d=(new Function("dynCall",
"rawFunction",f+"};\n"))(d,b)}"function"!==typeof d&&T("unknown function pointer with signature "+a+": "+b);return d}var me=void 0;function ne(a){a=oe(a);var b=S(a);K(a);return b}function pe(a,b){function d(a){f[a]||Id[a]||(Jd[a]?Jd[a].forEach(d):(e.push(a),f[a]=!0))}var e=[],f={};b.forEach(d);throw new me(a+": "+e.map(ne).join([", "]));}function qe(a,b){for(var d=[],e=0;e<a;e++)d.push(z[(b>>2)+e]);return d}function re(a){for(;a.length;){var b=a.pop();a.pop()(b)}}
function se(a){var b=Function;if(!(b instanceof Function))throw new TypeError("new_ called with constructor type "+typeof b+" which is not a function");var d=Ld(b.name||"unknownFunctionName",function(){});d.prototype=b.prototype;d=new d;a=b.apply(d,a);return a instanceof Object?a:d}var te=[],W=[{},{value:void 0},{value:null},{value:!0},{value:!1}];
function de(a){switch(a){case void 0:return 1;case null:return 2;case !0:return 3;case !1:return 4;default:var b=te.length?te.pop():W.length;W[b]={X:1,value:a};return b}}function be(a){if(null===a)return"null";var b=typeof a;return"object"===b||"array"===b||"function"===b?a.toString():""+a}function ue(a,b){switch(b){case 2:return function(a){return this.fromWireType(Da[a>>2])};case 3:return function(a){return this.fromWireType(Ea[a>>3])};default:throw new TypeError("Unknown float type: "+a);}}
function ve(a,b,d){switch(b){case 0:return d?function(a){return D[a]}:function(a){return E[a]};case 1:return d?function(a){return Ba[a>>1]}:function(a){return Ca[a>>1]};case 2:return d?function(a){return z[a>>2]}:function(a){return I[a>>2]};default:throw new TypeError("Unknown integer type: "+a);}}var we=u,xe=u+=48,ye=u+=16,ze=u+=16;u+=16;
function Ae(){function a(a){return(a=a.toTimeString().match(/\(([A-Za-z ]+)\)$/))?a[1]:"GMT"}if(!Be){Be=!0;z[ze>>2]=60*(new Date).getTimezoneOffset();var b=new Date(2E3,0,1),d=new Date(2E3,6,1);z[ye>>2]=Number(b.getTimezoneOffset()!=d.getTimezoneOffset());var e=a(b),f=a(d);e=qa(Oc(e),0);f=qa(Oc(f),0);d.getTimezoneOffset()<b.getTimezoneOffset()?(z[xe>>2]=e,z[xe+4>>2]=f):(z[xe>>2]=f,z[xe+4>>2]=e)}}var Be;function Ce(){void 0===Ce.start&&(Ce.start=Date.now());return 1E3*(Date.now()-Ce.start)|0}
function X(a){a=eval(F(a))+"";var b=wa(a);if(!X.u||X.u<b+1)X.u&&K(X.buffer),X.u=b+1,X.buffer=C(X.u);va(a,E,X.buffer,X.u);return X.buffer}var De=u;u+=16;var Ee,Y={};function Fe(a){if(0===a)return 0;a=F(a);if(!Y.hasOwnProperty(a))return 0;Fe.va&&K(Fe.va);a=Y[a];var b=wa(a)+1,d=C(b);d&&va(a,D,d,b);Fe.va=d;return Fe.va}function Ge(a){return Math.pow(2,a)}var Z=u;u+=48;qa(Oc("GMT"),2);
function He(a){a/=1E3;if((ba||q)&&self.performance&&self.performance.now)for(var b=self.performance.now();self.performance.now()-b<a;);else for(b=Date.now();Date.now()-b<a;);return 0}var Ie={},Je=1;function Ke(a,b){Ke.u||(Ke.u={});a in Ke.u||(c.dynCall_v(b),Ke.u[a]=1)}function Le(a){return 0===a%4&&(0!==a%100||0===a%400)}function Me(a,b){for(var d=0,e=0;e<=b;d+=a[e++]);return d}var Ne=[31,29,31,30,31,30,31,31,30,31,30,31],Oe=[31,28,31,30,31,30,31,31,30,31,30,31];
function Pe(a,b){for(a=new Date(a.getTime());0<b;){var d=a.getMonth(),e=(Le(a.getFullYear())?Ne:Oe)[d];if(b>e-a.getDate())b-=e-a.getDate()+1,a.setDate(1),11>d?a.setMonth(d+1):(a.setMonth(0),a.setFullYear(a.getFullYear()+1));else{a.setDate(a.getDate()+b);break}}return a}
function Qe(a,b,d,e){function f(a,b,d){for(a="number"===typeof a?a.toString():a||"";a.length<b;)a=d[0]+a;return a}function g(a,b){return f(a,b,"0")}function h(a,b){function d(a){return 0>a?-1:0<a?1:0}var e;0===(e=d(a.getFullYear()-b.getFullYear()))&&0===(e=d(a.getMonth()-b.getMonth()))&&(e=d(a.getDate()-b.getDate()));return e}function k(a){switch(a.getDay()){case 0:return new Date(a.getFullYear()-1,11,29);case 1:return a;case 2:return new Date(a.getFullYear(),0,3);case 3:return new Date(a.getFullYear(),
0,2);case 4:return new Date(a.getFullYear(),0,1);case 5:return new Date(a.getFullYear()-1,11,31);case 6:return new Date(a.getFullYear()-1,11,30)}}function l(a){a=Pe(new Date(a.s+1900,0,1),a.qa);var b=k(new Date(a.getFullYear()+1,0,4));return 0>=h(k(new Date(a.getFullYear(),0,4)),a)?0>=h(b,a)?a.getFullYear()+1:a.getFullYear():a.getFullYear()-1}var m=z[e+40>>2];e={wb:z[e>>2],vb:z[e+4>>2],pa:z[e+8>>2],S:z[e+12>>2],N:z[e+16>>2],s:z[e+20>>2],Wa:z[e+24>>2],qa:z[e+28>>2],Dd:z[e+32>>2],ub:z[e+36>>2],xb:m?
F(m):""};d=F(d);m={"%c":"%a %b %d %H:%M:%S %Y","%D":"%m/%d/%y","%F":"%Y-%m-%d","%h":"%b","%r":"%I:%M:%S %p","%R":"%H:%M","%T":"%H:%M:%S","%x":"%m/%d/%y","%X":"%H:%M:%S"};for(var p in m)d=d.replace(new RegExp(p,"g"),m[p]);var t="Sunday Monday Tuesday Wednesday Thursday Friday Saturday".split(" "),v="January February March April May June July August September October November December".split(" ");m={"%a":function(a){return t[a.Wa].substring(0,3)},"%A":function(a){return t[a.Wa]},"%b":function(a){return v[a.N].substring(0,
3)},"%B":function(a){return v[a.N]},"%C":function(a){return g((a.s+1900)/100|0,2)},"%d":function(a){return g(a.S,2)},"%e":function(a){return f(a.S,2," ")},"%g":function(a){return l(a).toString().substring(2)},"%G":function(a){return l(a)},"%H":function(a){return g(a.pa,2)},"%I":function(a){a=a.pa;0==a?a=12:12<a&&(a-=12);return g(a,2)},"%j":function(a){return g(a.S+Me(Le(a.s+1900)?Ne:Oe,a.N-1),3)},"%m":function(a){return g(a.N+1,2)},"%M":function(a){return g(a.vb,2)},"%n":function(){return"\n"},"%p":function(a){return 0<=
a.pa&&12>a.pa?"AM":"PM"},"%S":function(a){return g(a.wb,2)},"%t":function(){return"\t"},"%u":function(a){return(new Date(a.s+1900,a.N+1,a.S,0,0,0,0)).getDay()||7},"%U":function(a){var b=new Date(a.s+1900,0,1),d=0===b.getDay()?b:Pe(b,7-b.getDay());a=new Date(a.s+1900,a.N,a.S);return 0>h(d,a)?g(Math.ceil((31-d.getDate()+(Me(Le(a.getFullYear())?Ne:Oe,a.getMonth()-1)-31)+a.getDate())/7),2):0===h(d,b)?"01":"00"},"%V":function(a){var b=k(new Date(a.s+1900,0,4)),d=k(new Date(a.s+1901,0,4)),e=Pe(new Date(a.s+
1900,0,1),a.qa);return 0>h(e,b)?"53":0>=h(d,e)?"01":g(Math.ceil((b.getFullYear()<a.s+1900?a.qa+32-b.getDate():a.qa+1-b.getDate())/7),2)},"%w":function(a){return(new Date(a.s+1900,a.N+1,a.S,0,0,0,0)).getDay()},"%W":function(a){var b=new Date(a.s,0,1),d=1===b.getDay()?b:Pe(b,0===b.getDay()?1:7-b.getDay()+1);a=new Date(a.s+1900,a.N,a.S);return 0>h(d,a)?g(Math.ceil((31-d.getDate()+(Me(Le(a.getFullYear())?Ne:Oe,a.getMonth()-1)-31)+a.getDate())/7),2):0===h(d,b)?"01":"00"},"%y":function(a){return(a.s+1900).toString().substring(2)},
"%Y":function(a){return a.s+1900},"%z":function(a){a=a.ub;var b=0<=a;a=Math.abs(a)/60;return(b?"+":"-")+String("0000"+(a/60*100+a%60)).slice(-4)},"%Z":function(a){return a.xb},"%%":function(){return"%"}};for(p in m)0<=d.indexOf(p)&&(d=d.replace(new RegExp(p,"g"),m[p](e)));p=Oc(d,!1);if(p.length>b)return 0;D.set(p,a);return p.length-1}yd();$c=Array(4096);qd(N,"/");P("/tmp");P("/home");P("/home/web_user");
(function(){P("/dev");Mc(259,{read:function(){return 0},write:function(a,b,f,g){return g}});sd("/dev/null",259);Lc(1280,Pc);Lc(1536,Qc);sd("/dev/tty",1280);sd("/dev/tty1",1536);if("undefined"!==typeof crypto){var a=new Uint8Array(1);var b=function(){crypto.getRandomValues(a);return a[0]}}else b=r?function(){return require("crypto").randomBytes(1)[0]}:function(){return 256*Math.random()|0};Bd("random",b);Bd("urandom",b);P("/dev/shm");P("/dev/shm/tmp")})();P("/proc");P("/proc/self");P("/proc/self/fd");
qd({v:function(){var a=Sc("/proc/self","fd",16895,73);a.h={lookup:function(a,d){var b=Yc[+d];if(!b)throw new M(L.ea);a={parent:null,v:{Ua:"fake"},h:{readlink:function(){return b.path}}};return a.parent=a}};return a}},"/proc/self/fd");
Qa.unshift(function(){if(!c.noFSInit&&!zd){assert(!zd,"FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)");zd=!0;yd();c.stdin=c.stdin;c.stdout=c.stdout;c.stderr=c.stderr;c.stdin?Bd("stdin",c.stdin):td("/dev/tty","/dev/stdin");c.stdout?Bd("stdout",null,c.stdout):td("/dev/tty","/dev/stdout");c.stderr?Bd("stderr",null,c.stderr):td("/dev/tty1","/dev/stderr");var a=ud("/dev/stdin",
"r");assert(0===a.fd,"invalid handle for stdin ("+a.fd+")");a=ud("/dev/stdout","w");assert(1===a.fd,"invalid handle for stdout ("+a.fd+")");a=ud("/dev/stderr","w");assert(2===a.fd,"invalid handle for stderr ("+a.fd+")")}});Ra.push(function(){ad=!1});Sa.push(function(){zd=!1;var a=c._fflush;a&&a(0);for(a=0;a<Yc.length;a++){var b=Yc[a];b&&wd(b)}});Qa.unshift(function(){});Sa.push(function(){});if(r){var fs=require("fs"),Vc=require("path");O.tb()}for(var Re=Array(256),Se=0;256>Se;++Se)Re[Se]=String.fromCharCode(Se);
Gd=Re;Nd=c.BindingError=Md("BindingError");Od=c.InternalError=Md("InternalError");Vd.prototype.isAliasOf=function(a){if(!(this instanceof Vd&&a instanceof Vd))return!1;var b=this.c.o.i,d=this.c.j,e=a.c.o.i;for(a=a.c.j;b.F;)d=b.da(d),b=b.F;for(;e.F;)a=e.da(a),e=e.F;return b===e&&d===a};
Vd.prototype.clone=function(){this.c.j||Rd(this);if(this.c.ba)return this.c.count.value+=1,this;var a=this.c;a=Object.create(Object.getPrototypeOf(this),{c:{value:{count:a.count,U:a.U,ba:a.ba,j:a.j,o:a.o,B:a.B,D:a.D}}});a.c.count.value+=1;a.c.U=!1;return a};
Vd.prototype["delete"]=function(){this.c.j||Rd(this);this.c.U&&!this.c.ba&&T("Object already scheduled for deletion");--this.c.count.value;if(0===this.c.count.value){var a=this.c;a.B?a.D.R(a.B):a.o.i.R(a.j)}this.c.ba||(this.c.B=void 0,this.c.j=void 0)};Vd.prototype.isDeleted=function(){return!this.c.j};Vd.prototype.deleteLater=function(){this.c.j||Rd(this);this.c.U&&!this.c.ba&&T("Object already scheduled for deletion");Td.push(this);1===Td.length&&Sd&&Sd(Ud);this.c.U=!0;return this};
V.prototype.hb=function(a){this.Va&&(a=this.Va(a));return a};V.prototype.Z=function(a){this.R&&this.R(a)};V.prototype.argPackAdvance=8;V.prototype.readValueFromPointer=fe;V.prototype.deleteObject=function(a){if(null!==a)a["delete"]()};
V.prototype.fromWireType=function(a){function b(){return this.ka?je(this.i.V,{o:this.mb,j:d,D:this,B:a}):je(this.i.V,{o:this,j:a})}var d=this.hb(a);if(!d)return this.Z(a),null;var e=ie(this.i,d);if(void 0!==e){if(0===e.c.count.value)return e.c.j=d,e.c.B=a,e.clone();e=e.clone();this.Z(a);return e}e=this.i.fb(d);e=Wd[e];if(!e)return b.call(this);e=this.ja?e.bb:e.pointerType;var f=ge(d,this.i,e.i);return null===f?b.call(this):this.ka?je(e.i.V,{o:e,j:f,D:this,B:a}):je(e.i.V,{o:e,j:f})};
c.getInheritedInstanceCount=function(){return Object.keys(he).length};c.getLiveInheritedInstances=function(){var a=[],b;for(b in he)he.hasOwnProperty(b)&&a.push(he[b]);return a};c.flushPendingDeletes=Ud;c.setDelayFunction=function(a){Sd=a;Td.length&&Sd&&Sd(Ud)};me=c.UnboundTypeError=Md("UnboundTypeError");c.count_emval_handles=function(){for(var a=0,b=5;b<W.length;++b)void 0!==W[b]&&++a;return a};c.get_first_emval=function(){for(var a=5;a<W.length;++a)if(void 0!==W[a])return W[a];return null};
var Te,Ue;Ee?(Ue=z[De>>2],Te=z[Ue>>2]):(Ee=!0,Y.USER=Y.LOGNAME="web_user",Y.PATH="/",Y.PWD="/",Y.HOME="/home/web_user",Y.LANG="C.UTF-8",Y._=c.thisProgram,Te=ia(1024),Ue=ia(256),z[Ue>>2]=Te,z[De>>2]=Ue);var Ve=[],We=0,Xe;for(Xe in Y)if("string"===typeof Y[Xe]){var Ye=Xe+"="+Y[Xe];Ve.push(Ye);We+=Ye.length}if(1024<We)throw Error("Environment size exceeded TOTAL_ENV_SIZE!");
for(var Ze=0;Ze<Ve.length;Ze++){for(var $e=Ye=Ve[Ze],af=Te,bf=0;bf<$e.length;++bf)D[af++>>0]=$e.charCodeAt(bf);D[af>>0]=0;z[Ue+4*Ze>>2]=Te;Te+=Ye.length+1}z[Ue+4*Ve.length>>2]=0;y=ia(4);Ha=Ia=oa(u);Ja=Ha+Na;Ka=oa(Ja);z[y>>2]=Ka;la=!0;function Oc(a,b){var d=Array(wa(a)+1);a=va(a,d,0,d.length);b&&(d.length=a);return d}c.wasmTableSize=3583;c.wasmMaxTableSize=3583;c.$a={};
c.ab={abort:B,enlargeMemory:na,getTotalMemory:function(){return A},abortOnCannotGrowMemory:function(){B("Cannot enlarge memory arrays. Either (1) compile with  -s TOTAL_MEMORY=X  with X higher than the current value "+A+", (2) compile with  -s ALLOW_MEMORY_GROWTH=1  which allows increasing the size at runtime, or (3) if you want malloc to return NULL (0) instead of this abort, compile with  -s ABORTING_MALLOC=0 ")},invoke_di:function(a,b){try{return c.dynCall_di(a,b)}catch(d){if("number"!==typeof d&&
"longjmp"!==d)throw d;c.setThrew(1,0)}},invoke_dii:function(a,b,d){try{return c.dynCall_dii(a,b,d)}catch(e){if("number"!==typeof e&&"longjmp"!==e)throw e;c.setThrew(1,0)}},invoke_diiii:function(a,b,d,e,f){try{return c.dynCall_diiii(a,b,d,e,f)}catch(g){if("number"!==typeof g&&"longjmp"!==g)throw g;c.setThrew(1,0)}},invoke_fi:function(a,b){try{return c.dynCall_fi(a,b)}catch(d){if("number"!==typeof d&&"longjmp"!==d)throw d;c.setThrew(1,0)}},invoke_fii:function(a,b,d){try{return c.dynCall_fii(a,b,d)}catch(e){if("number"!==
typeof e&&"longjmp"!==e)throw e;c.setThrew(1,0)}},invoke_fiifffi:function(a,b,d,e,f,g,h){try{return c.dynCall_fiifffi(a,b,d,e,f,g,h)}catch(k){if("number"!==typeof k&&"longjmp"!==k)throw k;c.setThrew(1,0)}},invoke_fiii:function(a,b,d,e){try{return c.dynCall_fiii(a,b,d,e)}catch(f){if("number"!==typeof f&&"longjmp"!==f)throw f;c.setThrew(1,0)}},invoke_i:function(a){try{return c.dynCall_i(a)}catch(b){if("number"!==typeof b&&"longjmp"!==b)throw b;c.setThrew(1,0)}},invoke_ii:function(a,b){try{return c.dynCall_ii(a,
b)}catch(d){if("number"!==typeof d&&"longjmp"!==d)throw d;c.setThrew(1,0)}},invoke_iid:function(a,b,d){try{return c.dynCall_iid(a,b,d)}catch(e){if("number"!==typeof e&&"longjmp"!==e)throw e;c.setThrew(1,0)}},invoke_iififi:function(a,b,d,e,f,g){try{return c.dynCall_iififi(a,b,d,e,f,g)}catch(h){if("number"!==typeof h&&"longjmp"!==h)throw h;c.setThrew(1,0)}},invoke_iii:function(a,b,d){try{return c.dynCall_iii(a,b,d)}catch(e){if("number"!==typeof e&&"longjmp"!==e)throw e;c.setThrew(1,0)}},invoke_iiifii:function(a,
b,d,e,f,g){try{return c.dynCall_iiifii(a,b,d,e,f,g)}catch(h){if("number"!==typeof h&&"longjmp"!==h)throw h;c.setThrew(1,0)}},invoke_iiifiiiiiii:function(a,b,d,e,f,g,h,k,l,m,p){try{return c.dynCall_iiifiiiiiii(a,b,d,e,f,g,h,k,l,m,p)}catch(t){if("number"!==typeof t&&"longjmp"!==t)throw t;c.setThrew(1,0)}},invoke_iiii:function(a,b,d,e){try{return c.dynCall_iiii(a,b,d,e)}catch(f){if("number"!==typeof f&&"longjmp"!==f)throw f;c.setThrew(1,0)}},invoke_iiiidi:function(a,b,d,e,f,g){try{return c.dynCall_iiiidi(a,
b,d,e,f,g)}catch(h){if("number"!==typeof h&&"longjmp"!==h)throw h;c.setThrew(1,0)}},invoke_iiiii:function(a,b,d,e,f){try{return c.dynCall_iiiii(a,b,d,e,f)}catch(g){if("number"!==typeof g&&"longjmp"!==g)throw g;c.setThrew(1,0)}},invoke_iiiiifi:function(a,b,d,e,f,g,h){try{return c.dynCall_iiiiifi(a,b,d,e,f,g,h)}catch(k){if("number"!==typeof k&&"longjmp"!==k)throw k;c.setThrew(1,0)}},invoke_iiiiii:function(a,b,d,e,f,g){try{return c.dynCall_iiiiii(a,b,d,e,f,g)}catch(h){if("number"!==typeof h&&"longjmp"!==
h)throw h;c.setThrew(1,0)}},invoke_iiiiiii:function(a,b,d,e,f,g,h){try{return c.dynCall_iiiiiii(a,b,d,e,f,g,h)}catch(k){if("number"!==typeof k&&"longjmp"!==k)throw k;c.setThrew(1,0)}},invoke_iiiiiiii:function(a,b,d,e,f,g,h,k){try{return c.dynCall_iiiiiiii(a,b,d,e,f,g,h,k)}catch(l){if("number"!==typeof l&&"longjmp"!==l)throw l;c.setThrew(1,0)}},invoke_iiiiiiiif:function(a,b,d,e,f,g,h,k,l){try{return c.dynCall_iiiiiiiif(a,b,d,e,f,g,h,k,l)}catch(m){if("number"!==typeof m&&"longjmp"!==m)throw m;c.setThrew(1,
0)}},invoke_iiiiiiiii:function(a,b,d,e,f,g,h,k,l){try{return c.dynCall_iiiiiiiii(a,b,d,e,f,g,h,k,l)}catch(m){if("number"!==typeof m&&"longjmp"!==m)throw m;c.setThrew(1,0)}},invoke_iiiiiiiiii:function(a,b,d,e,f,g,h,k,l,m){try{return c.dynCall_iiiiiiiiii(a,b,d,e,f,g,h,k,l,m)}catch(p){if("number"!==typeof p&&"longjmp"!==p)throw p;c.setThrew(1,0)}},invoke_iiiiiiiiiiii:function(a,b,d,e,f,g,h,k,l,m,p,t){try{return c.dynCall_iiiiiiiiiiii(a,b,d,e,f,g,h,k,l,m,p,t)}catch(v){if("number"!==typeof v&&"longjmp"!==
v)throw v;c.setThrew(1,0)}},invoke_iiiiiiiiiiiiiiii:function(a,b,d,e,f,g,h,k,l,m,p,t,v,w,x,G){try{return c.dynCall_iiiiiiiiiiiiiiii(a,b,d,e,f,g,h,k,l,m,p,t,v,w,x,G)}catch(H){if("number"!==typeof H&&"longjmp"!==H)throw H;c.setThrew(1,0)}},invoke_iiiiiiiiiiiiiiiiii:function(a,b,d,e,f,g,h,k,l,m,p,t,v,w,x,G,H,ha){try{return c.dynCall_iiiiiiiiiiiiiiiiii(a,b,d,e,f,g,h,k,l,m,p,t,v,w,x,G,H,ha)}catch(ja){if("number"!==typeof ja&&"longjmp"!==ja)throw ja;c.setThrew(1,0)}},invoke_v:function(a){try{c.dynCall_v(a)}catch(b){if("number"!==
typeof b&&"longjmp"!==b)throw b;c.setThrew(1,0)}},invoke_vi:function(a,b){try{c.dynCall_vi(a,b)}catch(d){if("number"!==typeof d&&"longjmp"!==d)throw d;c.setThrew(1,0)}},invoke_vidii:function(a,b,d,e,f){try{c.dynCall_vidii(a,b,d,e,f)}catch(g){if("number"!==typeof g&&"longjmp"!==g)throw g;c.setThrew(1,0)}},invoke_vif:function(a,b,d){try{c.dynCall_vif(a,b,d)}catch(e){if("number"!==typeof e&&"longjmp"!==e)throw e;c.setThrew(1,0)}},invoke_viffffffff:function(a,b,d,e,f,g,h,k,l,m){try{c.dynCall_viffffffff(a,
b,d,e,f,g,h,k,l,m)}catch(p){if("number"!==typeof p&&"longjmp"!==p)throw p;c.setThrew(1,0)}},invoke_viffffffffffffffff:function(a,b,d,e,f,g,h,k,l,m,p,t,v,w,x,G,H,ha){try{c.dynCall_viffffffffffffffff(a,b,d,e,f,g,h,k,l,m,p,t,v,w,x,G,H,ha)}catch(ja){if("number"!==typeof ja&&"longjmp"!==ja)throw ja;c.setThrew(1,0)}},invoke_vii:function(a,b,d){try{c.dynCall_vii(a,b,d)}catch(e){if("number"!==typeof e&&"longjmp"!==e)throw e;c.setThrew(1,0)}},invoke_viid:function(a,b,d,e){try{c.dynCall_viid(a,b,d,e)}catch(f){if("number"!==
typeof f&&"longjmp"!==f)throw f;c.setThrew(1,0)}},invoke_viiddi:function(a,b,d,e,f,g){try{c.dynCall_viiddi(a,b,d,e,f,g)}catch(h){if("number"!==typeof h&&"longjmp"!==h)throw h;c.setThrew(1,0)}},invoke_viidi:function(a,b,d,e,f){try{c.dynCall_viidi(a,b,d,e,f)}catch(g){if("number"!==typeof g&&"longjmp"!==g)throw g;c.setThrew(1,0)}},invoke_viididii:function(a,b,d,e,f,g,h,k){try{c.dynCall_viididii(a,b,d,e,f,g,h,k)}catch(l){if("number"!==typeof l&&"longjmp"!==l)throw l;c.setThrew(1,0)}},invoke_viif:function(a,
b,d,e){try{c.dynCall_viif(a,b,d,e)}catch(f){if("number"!==typeof f&&"longjmp"!==f)throw f;c.setThrew(1,0)}},invoke_viiffff:function(a,b,d,e,f,g,h){try{c.dynCall_viiffff(a,b,d,e,f,g,h)}catch(k){if("number"!==typeof k&&"longjmp"!==k)throw k;c.setThrew(1,0)}},invoke_viifi:function(a,b,d,e,f){try{c.dynCall_viifi(a,b,d,e,f)}catch(g){if("number"!==typeof g&&"longjmp"!==g)throw g;c.setThrew(1,0)}},invoke_viifii:function(a,b,d,e,f,g){try{c.dynCall_viifii(a,b,d,e,f,g)}catch(h){if("number"!==typeof h&&"longjmp"!==
h)throw h;c.setThrew(1,0)}},invoke_viifiif:function(a,b,d,e,f,g,h){try{c.dynCall_viifiif(a,b,d,e,f,g,h)}catch(k){if("number"!==typeof k&&"longjmp"!==k)throw k;c.setThrew(1,0)}},invoke_viii:function(a,b,d,e){try{c.dynCall_viii(a,b,d,e)}catch(f){if("number"!==typeof f&&"longjmp"!==f)throw f;c.setThrew(1,0)}},invoke_viiid:function(a,b,d,e,f){try{c.dynCall_viiid(a,b,d,e,f)}catch(g){if("number"!==typeof g&&"longjmp"!==g)throw g;c.setThrew(1,0)}},invoke_viiidd:function(a,b,d,e,f,g){try{c.dynCall_viiidd(a,
b,d,e,f,g)}catch(h){if("number"!==typeof h&&"longjmp"!==h)throw h;c.setThrew(1,0)}},invoke_viiiddi:function(a,b,d,e,f,g,h){try{c.dynCall_viiiddi(a,b,d,e,f,g,h)}catch(k){if("number"!==typeof k&&"longjmp"!==k)throw k;c.setThrew(1,0)}},invoke_viiidi:function(a,b,d,e,f,g){try{c.dynCall_viiidi(a,b,d,e,f,g)}catch(h){if("number"!==typeof h&&"longjmp"!==h)throw h;c.setThrew(1,0)}},invoke_viiidii:function(a,b,d,e,f,g,h){try{c.dynCall_viiidii(a,b,d,e,f,g,h)}catch(k){if("number"!==typeof k&&"longjmp"!==k)throw k;
c.setThrew(1,0)}},invoke_viiif:function(a,b,d,e,f){try{c.dynCall_viiif(a,b,d,e,f)}catch(g){if("number"!==typeof g&&"longjmp"!==g)throw g;c.setThrew(1,0)}},invoke_viiifiii:function(a,b,d,e,f,g,h,k){try{c.dynCall_viiifiii(a,b,d,e,f,g,h,k)}catch(l){if("number"!==typeof l&&"longjmp"!==l)throw l;c.setThrew(1,0)}},invoke_viiii:function(a,b,d,e,f){try{c.dynCall_viiii(a,b,d,e,f)}catch(g){if("number"!==typeof g&&"longjmp"!==g)throw g;c.setThrew(1,0)}},invoke_viiiid:function(a,b,d,e,f,g){try{c.dynCall_viiiid(a,
b,d,e,f,g)}catch(h){if("number"!==typeof h&&"longjmp"!==h)throw h;c.setThrew(1,0)}},invoke_viiiidi:function(a,b,d,e,f,g,h){try{c.dynCall_viiiidi(a,b,d,e,f,g,h)}catch(k){if("number"!==typeof k&&"longjmp"!==k)throw k;c.setThrew(1,0)}},invoke_viiiidiii:function(a,b,d,e,f,g,h,k,l){try{c.dynCall_viiiidiii(a,b,d,e,f,g,h,k,l)}catch(m){if("number"!==typeof m&&"longjmp"!==m)throw m;c.setThrew(1,0)}},invoke_viiiii:function(a,b,d,e,f,g){try{c.dynCall_viiiii(a,b,d,e,f,g)}catch(h){if("number"!==typeof h&&"longjmp"!==
h)throw h;c.setThrew(1,0)}},invoke_viiiiidi:function(a,b,d,e,f,g,h,k){try{c.dynCall_viiiiidi(a,b,d,e,f,g,h,k)}catch(l){if("number"!==typeof l&&"longjmp"!==l)throw l;c.setThrew(1,0)}},invoke_viiiiifi:function(a,b,d,e,f,g,h,k){try{c.dynCall_viiiiifi(a,b,d,e,f,g,h,k)}catch(l){if("number"!==typeof l&&"longjmp"!==l)throw l;c.setThrew(1,0)}},invoke_viiiiii:function(a,b,d,e,f,g,h){try{c.dynCall_viiiiii(a,b,d,e,f,g,h)}catch(k){if("number"!==typeof k&&"longjmp"!==k)throw k;c.setThrew(1,0)}},invoke_viiiiiiddi:function(a,
b,d,e,f,g,h,k,l,m){try{c.dynCall_viiiiiiddi(a,b,d,e,f,g,h,k,l,m)}catch(p){if("number"!==typeof p&&"longjmp"!==p)throw p;c.setThrew(1,0)}},invoke_viiiiiidi:function(a,b,d,e,f,g,h,k,l){try{c.dynCall_viiiiiidi(a,b,d,e,f,g,h,k,l)}catch(m){if("number"!==typeof m&&"longjmp"!==m)throw m;c.setThrew(1,0)}},invoke_viiiiiii:function(a,b,d,e,f,g,h,k){try{c.dynCall_viiiiiii(a,b,d,e,f,g,h,k)}catch(l){if("number"!==typeof l&&"longjmp"!==l)throw l;c.setThrew(1,0)}},invoke_viiiiiiiddi:function(a,b,d,e,f,g,h,k,l,m,
p){try{c.dynCall_viiiiiiiddi(a,b,d,e,f,g,h,k,l,m,p)}catch(t){if("number"!==typeof t&&"longjmp"!==t)throw t;c.setThrew(1,0)}},invoke_viiiiiiii:function(a,b,d,e,f,g,h,k,l){try{c.dynCall_viiiiiiii(a,b,d,e,f,g,h,k,l)}catch(m){if("number"!==typeof m&&"longjmp"!==m)throw m;c.setThrew(1,0)}},invoke_viiiiiiiifi:function(a,b,d,e,f,g,h,k,l,m,p){try{c.dynCall_viiiiiiiifi(a,b,d,e,f,g,h,k,l,m,p)}catch(t){if("number"!==typeof t&&"longjmp"!==t)throw t;c.setThrew(1,0)}},invoke_viiiiiiiii:function(a,b,d,e,f,g,h,k,
l,m){try{c.dynCall_viiiiiiiii(a,b,d,e,f,g,h,k,l,m)}catch(p){if("number"!==typeof p&&"longjmp"!==p)throw p;c.setThrew(1,0)}},invoke_viiiiiiiiii:function(a,b,d,e,f,g,h,k,l,m,p){try{c.dynCall_viiiiiiiiii(a,b,d,e,f,g,h,k,l,m,p)}catch(t){if("number"!==typeof t&&"longjmp"!==t)throw t;c.setThrew(1,0)}},invoke_viiiiiiiiiiddi:function(a,b,d,e,f,g,h,k,l,m,p,t,v,w){try{c.dynCall_viiiiiiiiiiddi(a,b,d,e,f,g,h,k,l,m,p,t,v,w)}catch(x){if("number"!==typeof x&&"longjmp"!==x)throw x;c.setThrew(1,0)}},invoke_viiiiiiiiiii:function(a,
b,d,e,f,g,h,k,l,m,p,t){try{c.dynCall_viiiiiiiiiii(a,b,d,e,f,g,h,k,l,m,p,t)}catch(v){if("number"!==typeof v&&"longjmp"!==v)throw v;c.setThrew(1,0)}},invoke_viiiiiiiiiiii:function(a,b,d,e,f,g,h,k,l,m,p,t,v){try{c.dynCall_viiiiiiiiiiii(a,b,d,e,f,g,h,k,l,m,p,t,v)}catch(w){if("number"!==typeof w&&"longjmp"!==w)throw w;c.setThrew(1,0)}},invoke_viiiiiiiiiiiii:function(a,b,d,e,f,g,h,k,l,m,p,t,v,w){try{c.dynCall_viiiiiiiiiiiii(a,b,d,e,f,g,h,k,l,m,p,t,v,w)}catch(x){if("number"!==typeof x&&"longjmp"!==x)throw x;
c.setThrew(1,0)}},invoke_viiiiiiiiiiiiiii:function(a,b,d,e,f,g,h,k,l,m,p,t,v,w,x,G){try{c.dynCall_viiiiiiiiiiiiiii(a,b,d,e,f,g,h,k,l,m,p,t,v,w,x,G)}catch(H){if("number"!==typeof H&&"longjmp"!==H)throw H;c.setThrew(1,0)}},invoke_viiiiiiiiiiiiiiii:function(a,b,d,e,f,g,h,k,l,m,p,t,v,w,x,G,H){try{c.dynCall_viiiiiiiiiiiiiiii(a,b,d,e,f,g,h,k,l,m,p,t,v,w,x,G,H)}catch(ha){if("number"!==typeof ha&&"longjmp"!==ha)throw ha;c.setThrew(1,0)}},invoke_vij:function(a,b,d,e){try{c.dynCall_vij(a,b,d,e)}catch(f){if("number"!==
typeof f&&"longjmp"!==f)throw f;c.setThrew(1,0)}},_DMImage_Save:function(){c.printErr("missing function: DMImage_Save");B(-1)},__ZSt18uncaught_exceptionv:uc,___assert_fail:function(a,b,d,e){B("Assertion failed: "+F(a)+", at: "+[b?F(b):"unknown filename",d,e?F(e):"unknown function"])},___cxa_allocate_exception:function(a){return C(a)},___cxa_begin_catch:function(a){var b=J[a];b&&!b.La&&(b.La=!0,uc.u--);b&&(b.oa=!1);wc.push(a);(b=xc(a))&&J[b].X++;return a},___cxa_call_unexpected:function(a){c.printErr("Unexpected exception thrown, this is not properly supported - aborting");
pa=!0;throw a;},___cxa_end_catch:function(){c.setThrew(0);var a=wc.pop();if(a){if(a=xc(a)){var b=J[a];assert(0<b.X);b.X--;0!==b.X||b.oa||(b.Z&&c.dynCall_vi(b.Z,a),delete J[a],___cxa_free_exception(a))}vc=0}},___cxa_find_matching_catch_2:function(){return yc.apply(null,arguments)},___cxa_find_matching_catch_3:function(){return yc.apply(null,arguments)},___cxa_find_matching_catch_4:function(){return yc.apply(null,arguments)},___cxa_free_exception:___cxa_free_exception,___cxa_get_exception_ptr:function(a){return a},
___cxa_pure_virtual:function(){pa=!0;throw"Pure virtual function called!";},___cxa_rethrow:function(){var a=wc.pop();J[a].oa||(wc.push(a),J[a].oa=!0);vc=a;throw a;},___cxa_throw:function(a,b,d){J[a]={j:a,Ia:a,type:b,Z:d,X:0,La:!1,oa:!1};vc=a;"uncaught_exception"in uc?uc.u++:uc.u=1;throw a;},___lock:function(){},___map_file:function(){Bc(L.Y);return-1},___resumeException:function(a){vc||(vc=a);throw a;},___setErrNo:Bc,___syscall140:function(a,b){Q=b;try{var d=Ed();R();var e=R(),f=R(),g=R();xd(d,e,
g);z[f>>2]=d.position;d.wa&&0===e&&0===g&&(d.wa=null);return 0}catch(h){return"undefined"!==typeof FS&&h instanceof M||B(h),-h.J}},___syscall145:function(a,b){Q=b;try{var d=Ed(),e=R();a:{var f=R();for(b=a=0;b<f;b++){var g=z[e+(8*b+4)>>2],h=d,k=z[e+8*b>>2],l=g,m=void 0,p=D;if(0>l||0>m)throw new M(L.m);if(1===(h.flags&2097155))throw new M(L.ea);if(16384===(h.node.mode&61440))throw new M(L.ga);if(!h.g.read)throw new M(L.m);var t="undefined"!==typeof m;if(!t)m=h.position;else if(!h.seekable)throw new M(L.ha);
var v=h.g.read(h,p,k,l,m);t||(h.position+=v);var w=v;if(0>w){var x=-1;break a}a+=w;if(w<g)break}x=a}return x}catch(G){return"undefined"!==typeof FS&&G instanceof M||B(G),-G.J}},___syscall146:function(a,b){Q=b;try{var d=Ed(),e=R();a:{var f=R();for(b=a=0;b<f;b++){var g=d,h=z[e+8*b>>2],k=z[e+(8*b+4)>>2],l=D,m=void 0;if(0>k||0>m)throw new M(L.m);if(0===(g.flags&2097155))throw new M(L.ea);if(16384===(g.node.mode&61440))throw new M(L.ga);if(!g.g.write)throw new M(L.m);g.flags&1024&&xd(g,0,2);var p="undefined"!==
typeof m;if(!p)m=g.position;else if(!g.seekable)throw new M(L.ha);var t=g.g.write(g,l,h,k,m,void 0);p||(g.position+=t);try{if(g.path&&bd.onWriteToFile)bd.onWriteToFile(g.path)}catch(x){console.log("FS.trackingDelegate['onWriteToFile']('"+path+"') threw an exception: "+x.message)}var v=t;if(0>v){var w=-1;break a}a+=v}w=a}return w}catch(x){return"undefined"!==typeof FS&&x instanceof M||B(x),-x.J}},___syscall20:function(a,b){Q=b;return 42},___syscall221:function(a,b){Q=b;try{var d=Ed();switch(R()){case 0:var e=
R();return 0>e?-L.m:ud(d.path,d.flags,0,e).fd;case 1:case 2:return 0;case 3:return d.flags;case 4:return e=R(),d.flags|=e,0;case 12:case 12:return e=R(),Ba[e+0>>1]=2,0;case 13:case 14:case 13:case 14:return 0;case 16:case 8:return-L.m;case 9:return Bc(L.m),-1;default:return-L.m}}catch(f){return"undefined"!==typeof FS&&f instanceof M||B(f),-f.J}},___syscall5:function(a,b){Q=b;try{var d=F(R()),e=R(),f=R();return ud(d,e,f).fd}catch(g){return"undefined"!==typeof FS&&g instanceof M||B(g),-g.J}},___syscall54:function(a,
b){Q=b;try{var d=Ed(),e=R();switch(e){case 21509:case 21505:return d.tty?0:-L.T;case 21510:case 21511:case 21512:case 21506:case 21507:case 21508:return d.tty?0:-L.T;case 21519:if(!d.tty)return-L.T;var f=R();return z[f>>2]=0;case 21520:return d.tty?-L.m:-L.T;case 21531:a=f=R();if(!d.g.jb)throw new M(L.T);return d.g.jb(d,e,a);case 21523:return d.tty?0:-L.T;default:B("bad ioctl syscall "+e)}}catch(g){return"undefined"!==typeof FS&&g instanceof M||B(g),-g.J}},___syscall6:function(a,b){Q=b;try{var d=
Ed();wd(d);return 0}catch(e){return"undefined"!==typeof FS&&e instanceof M||B(e),-e.J}},___syscall85:function(a,b){Q=b;try{var d=F(R()),e=R();var f=R();if(0>=f)var g=-L.m;else{var h=ed(d),k=Math.min(f,wa(h)),l=D[e+k];va(h,E,e,f+1);D[e+k]=l;g=k}return g}catch(m){return"undefined"!==typeof FS&&m instanceof M||B(m),-m.J}},___syscall91:function(a,b){Q=b;try{var d=R(),e=R(),f=Dd[d];if(!f)return 0;if(e===f.Bd){var g=Yc[f.fd],h=f.flags,k=new Uint8Array(E.subarray(d,d+e));g&&g.g.na&&g.g.na(g,k,0,e,h);Dd[d]=
null;f.Za&&K(f.Cd)}return 0}catch(l){return"undefined"!==typeof FS&&l instanceof M||B(l),-l.J}},___unlock:function(){},__embind_register_bool:function(a,b,d,e,f){var g=Fd(d);b=S(b);U(a,{name:b,fromWireType:function(a){return!!a},toWireType:function(a,b){return b?e:f},argPackAdvance:8,readValueFromPointer:function(a){if(1===d)var e=D;else if(2===d)e=Ba;else if(4===d)e=z;else throw new TypeError("Unknown boolean type size: "+b);return this.fromWireType(e[a>>g])},I:null})},__embind_register_class:function(a,
b,d,e,f,g,h,k,l,m,p,t,v){p=S(p);g=le(f,g);k&&(k=le(h,k));m&&(m=le(l,m));v=le(t,v);var w=Kd(p);Yd(w,function(){pe("Cannot construct "+p+" due to unbound types",[e])});Qd([a,b,d],e?[e]:[],function(b){b=b[0];if(e){var d=b.i;var f=d.V}else f=Vd.prototype;b=Ld(w,function(){if(Object.getPrototypeOf(this)!==h)throw new Nd("Use 'new' to construct "+p);if(void 0===l.P)throw new Nd(p+" has no accessible constructor");var a=l.P[arguments.length];if(void 0===a)throw new Nd("Tried to invoke ctor of "+p+" with invalid number of parameters ("+
arguments.length+") - expected ("+Object.keys(l.P).toString()+") parameters instead!");return a.apply(this,arguments)});var h=Object.create(f,{constructor:{value:b}});b.prototype=h;var l=new Zd(p,b,h,v,d,g,k,m);d=new V(p,l,!0,!1,!1);f=new V(p+"*",l,!1,!1,!1);var t=new V(p+" const*",l,!1,!0,!1);Wd[a]={pointerType:f,bb:t};ke(w,b);return[d,f,t]})},__embind_register_class_constructor:function(a,b,d,e,f,g){var h=qe(b,d);f=le(e,f);Qd([],[a],function(a){a=a[0];var d="constructor "+a.name;void 0===a.i.P&&
(a.i.P=[]);if(void 0!==a.i.P[b-1])throw new Nd("Cannot register multiple constructors with identical number of parameters ("+(b-1)+") for class '"+a.name+"'! Overload resolution is currently only performed using the parameter count, not actual type info!");a.i.P[b-1]=function(){pe("Cannot construct "+a.name+" due to unbound types",h)};Qd([],h,function(e){a.i.P[b-1]=function(){arguments.length!==b-1&&T(d+" called with "+arguments.length+" arguments, expected "+(b-1));var a=[],h=Array(b);h[0]=g;for(var k=
1;k<b;++k)h[k]=e[k].toWireType(a,arguments[k-1]);h=f.apply(null,h);re(a);return e[0].fromWireType(h)};return[]});return[]})},__embind_register_class_function:function(a,b,d,e,f,g,h,k){var l=qe(d,e);b=S(b);g=le(f,g);Qd([],[a],function(a){function e(){pe("Cannot call "+f+" due to unbound types",l)}a=a[0];var f=a.name+"."+b;k&&a.i.nb.push(b);var m=a.i.V,w=m[b];void 0===w||void 0===w.H&&w.className!==a.name&&w.ia===d-2?(e.ia=d-2,e.className=a.name,m[b]=e):(Xd(m,b,f),m[b].H[d-2]=e);Qd([],l,function(e){var k=
f,l=a,p=g,t=e.length;2>t&&T("argTypes array size mismatch! Must at least get return value and 'this' types!");var v=null!==e[1]&&null!==l,w=!1;for(l=1;l<e.length;++l)if(null!==e[l]&&void 0===e[l].I){w=!0;break}var x="void"!==e[0].name,ka="",ua="";for(l=0;l<t-2;++l)ka+=(0!==l?", ":"")+"arg"+l,ua+=(0!==l?", ":"")+"arg"+l+"Wired";k="return function "+Kd(k)+"("+ka+") {\nif (arguments.length !== "+(t-2)+") {\nthrowBindingError('function "+k+" called with ' + arguments.length + ' arguments, expected "+
(t-2)+" args!');\n}\n";w&&(k+="var destructors = [];\n");var cd=w?"destructors":"null";ka="throwBindingError invoker fn runDestructors retType classParam".split(" ");p=[T,p,h,re,e[0],e[1]];v&&(k+="var thisWired = classParam.toWireType("+cd+", this);\n");for(l=0;l<t-2;++l)k+="var arg"+l+"Wired = argType"+l+".toWireType("+cd+", arg"+l+"); // "+e[l+2].name+"\n",ka.push("argType"+l),p.push(e[l+2]);v&&(ua="thisWired"+(0<ua.length?", ":"")+ua);k+=(x?"var rv = ":"")+"invoker(fn"+(0<ua.length?", ":"")+ua+
");\n";if(w)k+="runDestructors(destructors);\n";else for(l=v?1:2;l<e.length;++l)t=1===l?"thisWired":"arg"+(l-2)+"Wired",null!==e[l].I&&(k+=t+"_dtor("+t+"); // "+e[l].name+"\n",ka.push(t+"_dtor"),p.push(e[l].I));x&&(k+="var ret = retType.fromWireType(rv);\nreturn ret;\n");ka.push(k+"}\n");e=se(ka).apply(null,p);void 0===m[b].H?(e.ia=d-2,m[b]=e):m[b].H[d-2]=e;return[]});return[]})},__embind_register_emval:function(a,b){b=S(b);U(a,{name:b,fromWireType:function(a){var b=W[a].value;4<a&&0===--W[a].X&&
(W[a]=void 0,te.push(a));return b},toWireType:function(a,b){return de(b)},argPackAdvance:8,readValueFromPointer:fe,I:null})},__embind_register_float:function(a,b,d){d=Fd(d);b=S(b);U(a,{name:b,fromWireType:function(a){return a},toWireType:function(a,b){if("number"!==typeof b&&"boolean"!==typeof b)throw new TypeError('Cannot convert "'+be(b)+'" to '+this.name);return b},argPackAdvance:8,readValueFromPointer:ue(b,d),I:null})},__embind_register_integer:function(a,b,d,e,f){function g(a){return a}b=S(b);
-1===f&&(f=4294967295);var h=Fd(d);if(0===e){var k=32-8*d;g=function(a){return a<<k>>>k}}var l=-1!=b.indexOf("unsigned");U(a,{name:b,fromWireType:g,toWireType:function(a,d){if("number"!==typeof d&&"boolean"!==typeof d)throw new TypeError('Cannot convert "'+be(d)+'" to '+this.name);if(d<e||d>f)throw new TypeError('Passing a number "'+be(d)+'" from JS side to C/C++ side to an argument of type "'+b+'", which is outside the valid range ['+e+", "+f+"]!");return l?d>>>0:d|0},argPackAdvance:8,readValueFromPointer:ve(b,
h,0!==e),I:null})},__embind_register_memory_view:function(a,b,d){function e(a){a>>=2;var b=I;return new f(b.buffer,b[a+1],b[a])}var f=[Int8Array,Uint8Array,Int16Array,Uint16Array,Int32Array,Uint32Array,Float32Array,Float64Array][b];d=S(d);U(a,{name:d,fromWireType:e,argPackAdvance:8,readValueFromPointer:e},{ib:!0})},__embind_register_std_string:function(a,b){b=S(b);U(a,{name:b,fromWireType:function(a){for(var b=I[a>>2],d=Array(b),g=0;g<b;++g)d[g]=String.fromCharCode(E[a+4+g]);K(a);return d.join("")},
toWireType:function(a,b){function d(a,b){return a[b]}function e(a,b){return a.charCodeAt(b)}b instanceof ArrayBuffer&&(b=new Uint8Array(b));var h;b instanceof Uint8Array?h=d:b instanceof Uint8ClampedArray?h=d:b instanceof Int8Array?h=d:"string"===typeof b?h=e:T("Cannot pass non-string to std::string");var k=b.length,l=C(4+k);I[l>>2]=k;for(var m=0;m<k;++m){var p=h(b,m);255<p&&(K(l),T("String has UTF-16 code units that do not fit in 8 bits"));E[l+4+m]=p}null!==a&&a.push(K,l);return l},argPackAdvance:8,
readValueFromPointer:fe,I:function(a){K(a)}})},__embind_register_std_wstring:function(a,b,d){d=S(d);if(2===b){var e=function(){return Ca};var f=1}else 4===b&&(e=function(){return I},f=2);U(a,{name:d,fromWireType:function(a){for(var b=e(),d=I[a>>2],g=Array(d),m=a+4>>f,p=0;p<d;++p)g[p]=String.fromCharCode(b[m+p]);K(a);return g.join("")},toWireType:function(a,d){var g=e(),h=d.length,m=C(4+h*b);I[m>>2]=h;for(var p=m+4>>f,t=0;t<h;++t)g[p+t]=d.charCodeAt(t);null!==a&&a.push(K,m);return m},argPackAdvance:8,
readValueFromPointer:fe,I:function(a){K(a)}})},__embind_register_void:function(a,b){b=S(b);U(a,{Ad:!0,name:b,argPackAdvance:0,fromWireType:function(){},toWireType:function(){}})},_abort:function(){c.abort()},_asctime:function(a){var b=z[a>>2],d=z[a+4>>2],e=z[a+8>>2],f=z[a+12>>2];va("Sun Mon Tue Wed Thu Fri Sat".split(" ")[z[a+24>>2]]+" "+"Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec".split(" ")[z[a+16>>2]]+(10>f?"  ":" ")+f+(10>e?" 0":" ")+e+(10>d?":0":":")+d+(10>b?":0":":")+b+" "+(1900+z[a+20>>
2])+"\n",E,we,26);return we},_clock:Ce,_emscripten_memcpy_big:function(a,b,d){E.set(E.subarray(b,b+d),a);return a},_emscripten_run_script_string:X,_getenv:Fe,_llvm_eh_typeid_for:function(a){return a},_llvm_exp2_f64:function(){return Ge.apply(null,arguments)},_llvm_trap:function(){B("trap!")},_localtime:function(a){Ae();a=new Date(1E3*z[a>>2]);z[Z>>2]=a.getSeconds();z[Z+4>>2]=a.getMinutes();z[Z+8>>2]=a.getHours();z[Z+12>>2]=a.getDate();z[Z+16>>2]=a.getMonth();z[Z+20>>2]=a.getFullYear()-1900;z[Z+24>>
2]=a.getDay();var b=new Date(a.getFullYear(),0,1);z[Z+28>>2]=(a.getTime()-b.getTime())/864E5|0;z[Z+36>>2]=-(60*a.getTimezoneOffset());var d=(new Date(2E3,6,1)).getTimezoneOffset();b=b.getTimezoneOffset();a=(d!=b&&a.getTimezoneOffset()==Math.min(b,d))|0;z[Z+32>>2]=a;z[Z+40>>2]=z[xe+(a?4:0)>>2];return Z},_mktime:function(a){Ae();var b=new Date(z[a+20>>2]+1900,z[a+16>>2],z[a+12>>2],z[a+8>>2],z[a+4>>2],z[a>>2],0),d=z[a+32>>2],e=b.getTimezoneOffset(),f=new Date(b.getFullYear(),0,1),g=(new Date(2E3,6,1)).getTimezoneOffset(),
h=f.getTimezoneOffset(),k=Math.min(h,g);0>d?z[a+32>>2]=Number(g!=h&&k==e):0<d!=(k==e)&&(g=Math.max(h,g),b.setTime(b.getTime()+6E4*((0<d?k:g)-e)));z[a+24>>2]=b.getDay();z[a+28>>2]=(b.getTime()-f.getTime())/864E5|0;return b.getTime()/1E3|0},_nanosleep:function(a,b){var d=z[a>>2];a=z[a+4>>2];0!==b&&(z[b>>2]=0,z[b+4>>2]=0);return He(1E6*d+a/1E3)},_pthread_cond_wait:function(){return 0},_pthread_detach:function(){},_pthread_getspecific:function(a){return Ie[a]||0},_pthread_key_create:function(a){if(0==
a)return L.m;z[a>>2]=Je;Ie[Je]=0;Je++;return 0},_pthread_mutex_destroy:function(){},_pthread_mutex_init:function(){},_pthread_mutexattr_destroy:function(){},_pthread_mutexattr_init:function(){},_pthread_mutexattr_settype:function(){},_pthread_once:Ke,_pthread_setspecific:function(a,b){if(!(a in Ie))return L.m;Ie[a]=b;return 0},_pthread_spin_destroy:function(){return 0},_pthread_spin_init:function(){return 0},_pthread_spin_lock:function(){return 0},_pthread_spin_unlock:function(){return 0},_sem_close:function(){c.printErr("missing function: sem_close");
B(-1)},_sem_destroy:function(){},_sem_open:function(){c.printErr("missing function: sem_open");B(-1)},_sem_post:function(){},_sem_trywait:function(){},_sem_unlink:function(){c.printErr("missing function: sem_unlink");B(-1)},_strftime:Qe,_strftime_l:function(a,b,d,e){return Qe(a,b,d,e)},_time:function(a){var b=Date.now()/1E3|0;a&&(z[a>>2]=b);return b},_usleep:He,DYNAMICTOP_PTR:y,STACKTOP:Ia};var cf=c.asm(c.$a,c.ab,buffer);c.asm=cf;
var $a=c.__GLOBAL__I_000101=function(){return c.asm.__GLOBAL__I_000101.apply(null,arguments)},Vb=c.__GLOBAL__sub_I_AztecReader_cpp=function(){return c.asm.__GLOBAL__sub_I_AztecReader_cpp.apply(null,arguments)},ac=c.__GLOBAL__sub_I_BarcodeLocationOnSite_cpp=function(){return c.asm.__GLOBAL__sub_I_BarcodeLocationOnSite_cpp.apply(null,arguments)},lc=c.__GLOBAL__sub_I_BarcodeLocation_cpp=function(){return c.asm.__GLOBAL__sub_I_BarcodeLocation_cpp.apply(null,arguments)},bb=c.__GLOBAL__sub_I_BarcodeReaderCore_cpp=
function(){return c.asm.__GLOBAL__sub_I_BarcodeReaderCore_cpp.apply(null,arguments)},db=c.__GLOBAL__sub_I_BarcodeReaderInner_cpp=function(){return c.asm.__GLOBAL__sub_I_BarcodeReaderInner_cpp.apply(null,arguments)},mc=c.__GLOBAL__sub_I_CharacterSetECI_cpp=function(){return c.asm.__GLOBAL__sub_I_CharacterSetECI_cpp.apply(null,arguments)},Rb=c.__GLOBAL__sub_I_CodaBarReader_cpp=function(){return c.asm.__GLOBAL__sub_I_CodaBarReader_cpp.apply(null,arguments)},Qb=c.__GLOBAL__sub_I_Code128Reader_cpp=function(){return c.asm.__GLOBAL__sub_I_Code128Reader_cpp.apply(null,
arguments)},Pb=c.__GLOBAL__sub_I_Code39Reader_cpp=function(){return c.asm.__GLOBAL__sub_I_Code39Reader_cpp.apply(null,arguments)},Ob=c.__GLOBAL__sub_I_Code93Reader_cpp=function(){return c.asm.__GLOBAL__sub_I_Code93Reader_cpp.apply(null,arguments)},pb=c.__GLOBAL__sub_I_Common_cpp=function(){return c.asm.__GLOBAL__sub_I_Common_cpp.apply(null,arguments)},$b=c.__GLOBAL__sub_I_CropImage_cpp=function(){return c.asm.__GLOBAL__sub_I_CropImage_cpp.apply(null,arguments)},cb=c.__GLOBAL__sub_I_DMBarcodeDecoder_cpp=
function(){return c.asm.__GLOBAL__sub_I_DMBarcodeDecoder_cpp.apply(null,arguments)},gb=c.__GLOBAL__sub_I_DMFindlineByContours_cpp=function(){return c.asm.__GLOBAL__sub_I_DMFindlineByContours_cpp.apply(null,arguments)},hb=c.__GLOBAL__sub_I_DMFindline_cpp=function(){return c.asm.__GLOBAL__sub_I_DMFindline_cpp.apply(null,arguments)},ob=c.__GLOBAL__sub_I_DMLicenseInfo_cpp=function(){return c.asm.__GLOBAL__sub_I_DMLicenseInfo_cpp.apply(null,arguments)},Db=c.__GLOBAL__sub_I_DMLog_cpp=function(){return c.asm.__GLOBAL__sub_I_DMLog_cpp.apply(null,
arguments)},jc=c.__GLOBAL__sub_I_DMVersion_cpp=function(){return c.asm.__GLOBAL__sub_I_DMVersion_cpp.apply(null,arguments)},cc=c.__GLOBAL__sub_I_DataMask_cpp=function(){return c.asm.__GLOBAL__sub_I_DataMask_cpp.apply(null,arguments)},kc=c.__GLOBAL__sub_I_DataMatrixReader_cpp=function(){return c.asm.__GLOBAL__sub_I_DataMatrixReader_cpp.apply(null,arguments)},Ub=c.__GLOBAL__sub_I_Deblur_cpp=function(){return c.asm.__GLOBAL__sub_I_Deblur_cpp.apply(null,arguments)},fb=c.__GLOBAL__sub_I_DecodeInner_cpp=
function(){return c.asm.__GLOBAL__sub_I_DecodeInner_cpp.apply(null,arguments)},vb=c.__GLOBAL__sub_I_DynamsoftBarcodeReader_wasm_cpp=function(){return c.asm.__GLOBAL__sub_I_DynamsoftBarcodeReader_wasm_cpp.apply(null,arguments)},Nb=c.__GLOBAL__sub_I_EAN13Reader_cpp=function(){return c.asm.__GLOBAL__sub_I_EAN13Reader_cpp.apply(null,arguments)},Mb=c.__GLOBAL__sub_I_EAN8Reader_cpp=function(){return c.asm.__GLOBAL__sub_I_EAN8Reader_cpp.apply(null,arguments)},Jb=c.__GLOBAL__sub_I_ErrorCorrectionLevel_cpp=
function(){return c.asm.__GLOBAL__sub_I_ErrorCorrectionLevel_cpp.apply(null,arguments)},Zb=c.__GLOBAL__sub_I_FindBound_cpp=function(){return c.asm.__GLOBAL__sub_I_FindBound_cpp.apply(null,arguments)},Yb=c.__GLOBAL__sub_I_Fluctuation_cpp=function(){return c.asm.__GLOBAL__sub_I_Fluctuation_cpp.apply(null,arguments)},nb=c.__GLOBAL__sub_I_FormatParameters_cpp=function(){return c.asm.__GLOBAL__sub_I_FormatParameters_cpp.apply(null,arguments)},bc=c.__GLOBAL__sub_I_GenericGF_cpp=function(){return c.asm.__GLOBAL__sub_I_GenericGF_cpp.apply(null,
arguments)},mb=c.__GLOBAL__sub_I_GlobalParameters_cpp=function(){return c.asm.__GLOBAL__sub_I_GlobalParameters_cpp.apply(null,arguments)},Lb=c.__GLOBAL__sub_I_ITFReader_cpp=function(){return c.asm.__GLOBAL__sub_I_ITFReader_cpp.apply(null,arguments)},lb=c.__GLOBAL__sub_I_ImageParameters_cpp=function(){return c.asm.__GLOBAL__sub_I_ImageParameters_cpp.apply(null,arguments)},Tb=c.__GLOBAL__sub_I_Industry2of5Reader_cpp=function(){return c.asm.__GLOBAL__sub_I_Industry2of5Reader_cpp.apply(null,arguments)},
Bb=c.__GLOBAL__sub_I_JsonParser_cpp=function(){return c.asm.__GLOBAL__sub_I_JsonParser_cpp.apply(null,arguments)},ab=c.__GLOBAL__sub_I_JsonReader_cpp=function(){return c.asm.__GLOBAL__sub_I_JsonReader_cpp.apply(null,arguments)},Xb=c.__GLOBAL__sub_I_LineStatistics_cpp=function(){return c.asm.__GLOBAL__sub_I_LineStatistics_cpp.apply(null,arguments)},kb=c.__GLOBAL__sub_I_LogParamUtil_cpp=function(){return c.asm.__GLOBAL__sub_I_LogParamUtil_cpp.apply(null,arguments)},rb=c.__GLOBAL__sub_I_Mode_cpp=function(){return c.asm.__GLOBAL__sub_I_Mode_cpp.apply(null,
arguments)},ec=c.__GLOBAL__sub_I_ModulusGF_cpp=function(){return c.asm.__GLOBAL__sub_I_ModulusGF_cpp.apply(null,arguments)},tc=c.__GLOBAL__sub_I_MultiFormatOneDReader_cpp=function(){return c.asm.__GLOBAL__sub_I_MultiFormatOneDReader_cpp.apply(null,arguments)},eb=c.__GLOBAL__sub_I_MultiFormatReader_cpp=function(){return c.asm.__GLOBAL__sub_I_MultiFormatReader_cpp.apply(null,arguments)},sc=c.__GLOBAL__sub_I_MultiFormatUPCEANReader_cpp=function(){return c.asm.__GLOBAL__sub_I_MultiFormatUPCEANReader_cpp.apply(null,
arguments)},rc=c.__GLOBAL__sub_I_OneDReader_cpp=function(){return c.asm.__GLOBAL__sub_I_OneDReader_cpp.apply(null,arguments)},Ib=c.__GLOBAL__sub_I_OneD_StandardLization_cpp=function(){return c.asm.__GLOBAL__sub_I_OneD_StandardLization_cpp.apply(null,arguments)},hc=c.__GLOBAL__sub_I_PDF417CodewordDecoder_cpp=function(){return c.asm.__GLOBAL__sub_I_PDF417CodewordDecoder_cpp.apply(null,arguments)},fc=c.__GLOBAL__sub_I_PDF417DecodedBitStreamParser_cpp=function(){return c.asm.__GLOBAL__sub_I_PDF417DecodedBitStreamParser_cpp.apply(null,
arguments)},ic=c.__GLOBAL__sub_I_PDF417Reader_cpp=function(){return c.asm.__GLOBAL__sub_I_PDF417Reader_cpp.apply(null,arguments)},Sb=c.__GLOBAL__sub_I_PDF417_Deblur_cpp=function(){return c.asm.__GLOBAL__sub_I_PDF417_Deblur_cpp.apply(null,arguments)},Hb=c.__GLOBAL__sub_I_PDF417_standardLization_cpp=function(){return c.asm.__GLOBAL__sub_I_PDF417_standardLization_cpp.apply(null,arguments)},jb=c.__GLOBAL__sub_I_ParameterPool_cpp=function(){return c.asm.__GLOBAL__sub_I_ParameterPool_cpp.apply(null,arguments)},
Wb=c.__GLOBAL__sub_I_QRBarcodeLocation_cpp=function(){return c.asm.__GLOBAL__sub_I_QRBarcodeLocation_cpp.apply(null,arguments)},dc=c.__GLOBAL__sub_I_QRCodeReader_cpp=function(){return c.asm.__GLOBAL__sub_I_QRCodeReader_cpp.apply(null,arguments)},qb=c.__GLOBAL__sub_I_QRVersion_cpp=function(){return c.asm.__GLOBAL__sub_I_QRVersion_cpp.apply(null,arguments)},Gb=c.__GLOBAL__sub_I_QR_StandardLization_cpp=function(){return c.asm.__GLOBAL__sub_I_QR_StandardLization_cpp.apply(null,arguments)},nc=c.__GLOBAL__sub_I_Reader_cpp=
function(){return c.asm.__GLOBAL__sub_I_Reader_cpp.apply(null,arguments)},ib=c.__GLOBAL__sub_I_RegionDefinition_cpp=function(){return c.asm.__GLOBAL__sub_I_RegionDefinition_cpp.apply(null,arguments)},Kb=c.__GLOBAL__sub_I_RestoreColor_cpp=function(){return c.asm.__GLOBAL__sub_I_RestoreColor_cpp.apply(null,arguments)},Fb=c.__GLOBAL__sub_I_TextFilter_cpp=function(){return c.asm.__GLOBAL__sub_I_TextFilter_cpp.apply(null,arguments)},qc=c.__GLOBAL__sub_I_UPCAReader_cpp=function(){return c.asm.__GLOBAL__sub_I_UPCAReader_cpp.apply(null,
arguments)},pc=c.__GLOBAL__sub_I_UPCEANReader_cpp=function(){return c.asm.__GLOBAL__sub_I_UPCEANReader_cpp.apply(null,arguments)},oc=c.__GLOBAL__sub_I_UPCEReader_cpp=function(){return c.asm.__GLOBAL__sub_I_UPCEReader_cpp.apply(null,arguments)},ub=c.__GLOBAL__sub_I_bind_cpp=function(){return c.asm.__GLOBAL__sub_I_bind_cpp.apply(null,arguments)},zb=c.__GLOBAL__sub_I_clahe_cpp=function(){return c.asm.__GLOBAL__sub_I_clahe_cpp.apply(null,arguments)},Cb=c.__GLOBAL__sub_I_dsGlobalMem_cpp=function(){return c.asm.__GLOBAL__sub_I_dsGlobalMem_cpp.apply(null,
arguments)},yb=c.__GLOBAL__sub_I_generalized_hough_cpp=function(){return c.asm.__GLOBAL__sub_I_generalized_hough_cpp.apply(null,arguments)},xb=c.__GLOBAL__sub_I_histogram_cpp=function(){return c.asm.__GLOBAL__sub_I_histogram_cpp.apply(null,arguments)},wb=c.__GLOBAL__sub_I_imgwarp_cpp=function(){return c.asm.__GLOBAL__sub_I_imgwarp_cpp.apply(null,arguments)},tb=c.__GLOBAL__sub_I_iostream_cpp=function(){return c.asm.__GLOBAL__sub_I_iostream_cpp.apply(null,arguments)},Eb=c.__GLOBAL__sub_I_json_value_cpp=
function(){return c.asm.__GLOBAL__sub_I_json_value_cpp.apply(null,arguments)},sb=c.__GLOBAL__sub_I_persistence_cpp=function(){return c.asm.__GLOBAL__sub_I_persistence_cpp.apply(null,arguments)},Ab=c.__GLOBAL__sub_I_system_cpp=function(){return c.asm.__GLOBAL__sub_I_system_cpp.apply(null,arguments)};c.___cxa_can_catch=function(){return c.asm.___cxa_can_catch.apply(null,arguments)};c.___cxa_is_pointer_type=function(){return c.asm.___cxa_is_pointer_type.apply(null,arguments)};
c.___errno_location=function(){return c.asm.___errno_location.apply(null,arguments)};var oe=c.___getTypeName=function(){return c.asm.___getTypeName.apply(null,arguments)},La=c._emscripten_replace_memory=function(){return c.asm._emscripten_replace_memory.apply(null,arguments)},K=c._free=function(){return c.asm._free.apply(null,arguments)},C=c._malloc=function(){return c.asm._malloc.apply(null,arguments)},zc=c.setTempRet0=function(){return c.asm.setTempRet0.apply(null,arguments)};
c.setThrew=function(){return c.asm.setThrew.apply(null,arguments)};var ra=c.stackAlloc=function(){return c.asm.stackAlloc.apply(null,arguments)};c.dynCall_di=function(){return c.asm.dynCall_di.apply(null,arguments)};c.dynCall_dii=function(){return c.asm.dynCall_dii.apply(null,arguments)};c.dynCall_diiid=function(){return c.asm.dynCall_diiid.apply(null,arguments)};c.dynCall_diiii=function(){return c.asm.dynCall_diiii.apply(null,arguments)};
c.dynCall_fi=function(){return c.asm.dynCall_fi.apply(null,arguments)};c.dynCall_fii=function(){return c.asm.dynCall_fii.apply(null,arguments)};c.dynCall_fiifffi=function(){return c.asm.dynCall_fiifffi.apply(null,arguments)};c.dynCall_fiii=function(){return c.asm.dynCall_fiii.apply(null,arguments)};c.dynCall_i=function(){return c.asm.dynCall_i.apply(null,arguments)};c.dynCall_idd=function(){return c.asm.dynCall_idd.apply(null,arguments)};
c.dynCall_ii=function(){return c.asm.dynCall_ii.apply(null,arguments)};c.dynCall_iid=function(){return c.asm.dynCall_iid.apply(null,arguments)};c.dynCall_iififi=function(){return c.asm.dynCall_iififi.apply(null,arguments)};c.dynCall_iii=function(){return c.asm.dynCall_iii.apply(null,arguments)};c.dynCall_iiifii=function(){return c.asm.dynCall_iiifii.apply(null,arguments)};c.dynCall_iiifiiiiiii=function(){return c.asm.dynCall_iiifiiiiiii.apply(null,arguments)};
c.dynCall_iiii=function(){return c.asm.dynCall_iiii.apply(null,arguments)};c.dynCall_iiiidi=function(){return c.asm.dynCall_iiiidi.apply(null,arguments)};c.dynCall_iiiii=function(){return c.asm.dynCall_iiiii.apply(null,arguments)};c.dynCall_iiiiid=function(){return c.asm.dynCall_iiiiid.apply(null,arguments)};c.dynCall_iiiiifi=function(){return c.asm.dynCall_iiiiifi.apply(null,arguments)};c.dynCall_iiiiii=function(){return c.asm.dynCall_iiiiii.apply(null,arguments)};
c.dynCall_iiiiiid=function(){return c.asm.dynCall_iiiiiid.apply(null,arguments)};c.dynCall_iiiiiii=function(){return c.asm.dynCall_iiiiiii.apply(null,arguments)};c.dynCall_iiiiiiii=function(){return c.asm.dynCall_iiiiiiii.apply(null,arguments)};c.dynCall_iiiiiiiif=function(){return c.asm.dynCall_iiiiiiiif.apply(null,arguments)};c.dynCall_iiiiiiiii=function(){return c.asm.dynCall_iiiiiiiii.apply(null,arguments)};c.dynCall_iiiiiiiiii=function(){return c.asm.dynCall_iiiiiiiiii.apply(null,arguments)};
c.dynCall_iiiiiiiiiiii=function(){return c.asm.dynCall_iiiiiiiiiiii.apply(null,arguments)};c.dynCall_iiiiiiiiiiiiiiii=function(){return c.asm.dynCall_iiiiiiiiiiiiiiii.apply(null,arguments)};c.dynCall_iiiiiiiiiiiiiiiiii=function(){return c.asm.dynCall_iiiiiiiiiiiiiiiiii.apply(null,arguments)};c.dynCall_iiiiij=function(){return c.asm.dynCall_iiiiij.apply(null,arguments)};c.dynCall_ji=function(){return c.asm.dynCall_ji.apply(null,arguments)};c.dynCall_v=function(){return c.asm.dynCall_v.apply(null,arguments)};
c.dynCall_vi=function(){return c.asm.dynCall_vi.apply(null,arguments)};c.dynCall_vid=function(){return c.asm.dynCall_vid.apply(null,arguments)};c.dynCall_vidii=function(){return c.asm.dynCall_vidii.apply(null,arguments)};c.dynCall_vif=function(){return c.asm.dynCall_vif.apply(null,arguments)};c.dynCall_viffffffff=function(){return c.asm.dynCall_viffffffff.apply(null,arguments)};c.dynCall_viffffffffffffffff=function(){return c.asm.dynCall_viffffffffffffffff.apply(null,arguments)};
c.dynCall_vii=function(){return c.asm.dynCall_vii.apply(null,arguments)};c.dynCall_viid=function(){return c.asm.dynCall_viid.apply(null,arguments)};c.dynCall_viiddi=function(){return c.asm.dynCall_viiddi.apply(null,arguments)};c.dynCall_viidi=function(){return c.asm.dynCall_viidi.apply(null,arguments)};c.dynCall_viididii=function(){return c.asm.dynCall_viididii.apply(null,arguments)};c.dynCall_viif=function(){return c.asm.dynCall_viif.apply(null,arguments)};
c.dynCall_viiffff=function(){return c.asm.dynCall_viiffff.apply(null,arguments)};c.dynCall_viiffi=function(){return c.asm.dynCall_viiffi.apply(null,arguments)};c.dynCall_viifi=function(){return c.asm.dynCall_viifi.apply(null,arguments)};c.dynCall_viifii=function(){return c.asm.dynCall_viifii.apply(null,arguments)};c.dynCall_viifiif=function(){return c.asm.dynCall_viifiif.apply(null,arguments)};c.dynCall_viii=function(){return c.asm.dynCall_viii.apply(null,arguments)};
c.dynCall_viiid=function(){return c.asm.dynCall_viiid.apply(null,arguments)};c.dynCall_viiidd=function(){return c.asm.dynCall_viiidd.apply(null,arguments)};c.dynCall_viiiddi=function(){return c.asm.dynCall_viiiddi.apply(null,arguments)};c.dynCall_viiidi=function(){return c.asm.dynCall_viiidi.apply(null,arguments)};c.dynCall_viiidii=function(){return c.asm.dynCall_viiidii.apply(null,arguments)};c.dynCall_viiif=function(){return c.asm.dynCall_viiif.apply(null,arguments)};
c.dynCall_viiifiii=function(){return c.asm.dynCall_viiifiii.apply(null,arguments)};c.dynCall_viiii=function(){return c.asm.dynCall_viiii.apply(null,arguments)};c.dynCall_viiiid=function(){return c.asm.dynCall_viiiid.apply(null,arguments)};c.dynCall_viiiidi=function(){return c.asm.dynCall_viiiidi.apply(null,arguments)};c.dynCall_viiiidiii=function(){return c.asm.dynCall_viiiidiii.apply(null,arguments)};c.dynCall_viiiii=function(){return c.asm.dynCall_viiiii.apply(null,arguments)};
c.dynCall_viiiiidi=function(){return c.asm.dynCall_viiiiidi.apply(null,arguments)};c.dynCall_viiiiifi=function(){return c.asm.dynCall_viiiiifi.apply(null,arguments)};c.dynCall_viiiiii=function(){return c.asm.dynCall_viiiiii.apply(null,arguments)};c.dynCall_viiiiiiddi=function(){return c.asm.dynCall_viiiiiiddi.apply(null,arguments)};c.dynCall_viiiiiidi=function(){return c.asm.dynCall_viiiiiidi.apply(null,arguments)};c.dynCall_viiiiiii=function(){return c.asm.dynCall_viiiiiii.apply(null,arguments)};
c.dynCall_viiiiiiiddi=function(){return c.asm.dynCall_viiiiiiiddi.apply(null,arguments)};c.dynCall_viiiiiiii=function(){return c.asm.dynCall_viiiiiiii.apply(null,arguments)};c.dynCall_viiiiiiiifi=function(){return c.asm.dynCall_viiiiiiiifi.apply(null,arguments)};c.dynCall_viiiiiiiii=function(){return c.asm.dynCall_viiiiiiiii.apply(null,arguments)};c.dynCall_viiiiiiiiii=function(){return c.asm.dynCall_viiiiiiiiii.apply(null,arguments)};
c.dynCall_viiiiiiiiiiddi=function(){return c.asm.dynCall_viiiiiiiiiiddi.apply(null,arguments)};c.dynCall_viiiiiiiiiii=function(){return c.asm.dynCall_viiiiiiiiiii.apply(null,arguments)};c.dynCall_viiiiiiiiiiii=function(){return c.asm.dynCall_viiiiiiiiiiii.apply(null,arguments)};c.dynCall_viiiiiiiiiiiii=function(){return c.asm.dynCall_viiiiiiiiiiiii.apply(null,arguments)};c.dynCall_viiiiiiiiiiiiiii=function(){return c.asm.dynCall_viiiiiiiiiiiiiii.apply(null,arguments)};
c.dynCall_viiiiiiiiiiiiiiii=function(){return c.asm.dynCall_viiiiiiiiiiiiiiii.apply(null,arguments)};c.dynCall_viijii=function(){return c.asm.dynCall_viijii.apply(null,arguments)};c.dynCall_vij=function(){return c.asm.dynCall_vij.apply(null,arguments)};c.asm=cf;function fa(a){this.name="ExitStatus";this.message="Program terminated with exit("+a+")";this.status=a}fa.prototype=Error();fa.prototype.constructor=fa;Ya=function df(){c.calledRun||ef();c.calledRun||(Ya=df)};
function ef(){function a(){if(!c.calledRun&&(c.calledRun=!0,!pa)){Ua||(Ua=!0,Oa(Qa));Oa(Ra);if(c.onRuntimeInitialized)c.onRuntimeInitialized();if(c.postRun)for("function"==typeof c.postRun&&(c.postRun=[c.postRun]);c.postRun.length;){var a=c.postRun.shift();Ta.unshift(a)}Oa(Ta)}}if(!(0<Wa)){if(c.preRun)for("function"==typeof c.preRun&&(c.preRun=[c.preRun]);c.preRun.length;)Va();Oa(Pa);0<Wa||c.calledRun||(c.setStatus?(c.setStatus("Running..."),setTimeout(function(){setTimeout(function(){c.setStatus("")},
1);a()},1)):a())}}c.run=ef;c.exit=function(a,b){if(!b||!c.noExitRuntime||0!==a){if(!c.noExitRuntime&&(pa=!0,Ia=void 0,Oa(Sa),c.onExit))c.onExit(a);r&&process.exit(a);c.quit(a,new fa(a))}};function B(a){if(c.onAbort)c.onAbort(a);void 0!==a?(c.print(a),c.printErr(a),a=JSON.stringify(a)):a="";pa=!0;throw"abort("+a+"). Build with -s ASSERTIONS=1 for more info.";}c.abort=B;if(c.preInit)for("function"==typeof c.preInit&&(c.preInit=[c.preInit]);0<c.preInit.length;)c.preInit.pop()();c.noExitRuntime=!0;ef();

                /* eslint-enable */
            }).then(function(){
                BR._loadWasmStatus = 'loaded';
                BR._loadWasmTaskQueue.next();
                resolve();
            }).catch(function(ex){
                BR._loadWasmStatus = ex;
                BR._loadWasmTaskQueue.next();
                reject(ex);
            });
        }
    }, null, ['loading' == BR._loadWasmStatus]);
});};

dynamsoft.dbrEnv.bAutoLoadWasm = (dynamsoft.dbrEnv.bAutoLoadWasm || dynamsoft.dbrEnv.bAutoLoadWasm === undefined) ? true : false;
if(dynamsoft.dbrEnv.bAutoLoadWasm && !dynamsoft.BarcodeReader._BarcodeReaderWasm){
    // only AutoLoad once, though someone may add dbr.js more than once
    dynamsoft.BarcodeReader._BarcodeReaderWasm = function(){
        throw Error("'Constructor BarcodeReader(licenseKey)': The wasm hasn't finish loading.");
    };

    dynamsoft.BarcodeReader.loadWasm().then(function(){
        if(dynamsoft.dbrEnv.onAutoLoadWasmSuccess){dynamsoft.dbrEnv.onAutoLoadWasmSuccess();}
    },function(status){
        if(dynamsoft.dbrEnv.onAutoLoadWasmError){dynamsoft.dbrEnv.onAutoLoadWasmError(status);}
    });
}


